@@ -4,6 +4,11 @@ CLI_CONFIG = {
         "subcommands": ["aws"],
         "dyne": "pop_create",
     },
+    "sync_sls_name_and_name_tag": {
+        "action": "store_true",
+        "subcommands": ["state"],
+        "dyne": "idem",
+    },
 }
 CONFIG = {
     # pop-create options
@@ -13,6 +18,11 @@ CONFIG = {
         "help": "The cloud services to target, defaults to all",
         "dyne": "pop_create",
     },
+    "sync_sls_name_and_name_tag": {
+        "default": False,
+        "help": "If set to true, tags for a resource will be modified to use the SLS name as a Name tag",
+        "dyne": "idem",
+    },
 }
 SUBCOMMANDS = {
     "aws": {
