@@ -10,7 +10,7 @@ async def get(hub, ctx, name: str, resource_id: str):
         hub: required for functions in hub.
         ctx: context.
         name(str): An Idem name of the IAM group.
-        resource_id(str, optional): AWS IAM group name.
+        resource_id(str, Optional): AWS IAM group name.
 
     """
     result = dict(comment=[], ret=None, result=True)
