@@ -15,13 +15,37 @@ async def update_tags(
     Update tags of AWS IAM OpenID Connect Provider
 
     Args:
-        resource_id: The Amazon Resource Name (ARN) of the IAM OpenID Connect provider
-        old_tags: dict of old tags
-        new_tags: dict of new tags
+        resource_id (str):
+            The Amazon Resource Name (ARN) of the IAM OpenID Connect provider
+
+        old_tags (dict):
+            Dict of old tags
+
+        new_tags (dict):
+            Dict of new tags
 
     Returns:
-        {"result": True|False, "comment": Tuple, "ret": Dict of updated tags}
+        Dict[str, Any]:
+            Dict of updated tags
 
+    Examples:
+        Calling this exec module function from the cli with filters
+
+        .. code-block:: bash
+
+            idem exec aws.iam.open_id_connect_provider.update_tags name="my_resource" old_tags="{}" new_tags="{}"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.open_id_connect_provider.update_tags
+                - kwargs:
+                    name: my_resource
+                    old_tags: {}
+                    new_tags: {}
     """
     tags_to_add = {}
     tags_to_remove = {}
@@ -82,12 +106,37 @@ async def update_thumbprints(
     Update thumbprints of AWS IAM OpenID Connect Provider
 
     Args:
-        resource_id: The Amazon Resource Name (ARN) of the IAM OpenID Connect provider
-        old_thumbprints: list of old thumbprints
-        new_thumbprints: list of new thumbprints
+        resource_id (str):
+            The Amazon Resource Name (ARN) of the IAM OpenID Connect provider
+
+        old_thumbprints (list):
+            List of old thumbprints
+
+        new_thumbprints (list):
+            List of new thumbprints
 
     Returns:
-        {"result": True|False, "comment": Tuple, "ret": Dict}
+        Dict[str, Any]:
+            List of updated thumbprints
+
+    Examples:
+        Calling this exec module function from the cli with filters
+
+        .. code-block:: bash
+
+            idem exec aws.iam.open_id_connect_provider.update_thumbprints name="my_resource" old_thumbprints="[]" new_thumbprints="[]"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.open_id_connect_provider.update_thumbprints
+                - kwargs:
+                    name: my_resource
+                    old_thumbprints: []
+                    new_thumbprints: []
     """
     result = dict(comment=(), result=True, ret=None)
     if not ctx.get("test", False):
@@ -122,13 +171,37 @@ async def update_client_ids(
     Update clientIDs of AWS IAM OpenID Connect Provider
 
     Args:
-        resource_id: The Amazon Resource Name (ARN) of the IAM OpenID Connect provider
-        old_client_ids: list of old clientIDs
-        new_client_ids: list of new clientIDs
+        resource_id (str):
+            The Amazon Resource Name (ARN) of the IAM OpenID Connect provider
+
+        old_client_ids (list):
+            List of old clientIDs
+
+        new_client_ids (list):
+            List of new clientIDs
 
     Returns:
-        {"result": True|False, "comment": Tuple, "ret": Dict}
+        Dict[str, Any]:
+            List of updated client_ids
 
+    Examples:
+        Calling this exec module function from the cli with filters
+
+        .. code-block:: bash
+
+            idem exec aws.iam.open_id_connect_provider.update_client_ids name="my_resource" old_client_ids="[]" new_client_ids="[]"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.open_id_connect_provider.update_client_ids
+                - kwargs:
+                    name: my_resource
+                    old_client_ids: []
+                    new_client_ids: []
     """
     old_clients_list = copy.deepcopy(old_client_ids)
     clients_result = copy.deepcopy(old_clients_list)
