@@ -43,7 +43,9 @@ async def get(hub, ctx, name: str, resource_id: str) -> Dict:
         )
         return result
 
-    result["ret"] = await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present(
+    result[
+        "ret"
+    ] = await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present_async(
         ctx, idem_resource_name=resource_id
     )
     return result
@@ -52,7 +54,7 @@ async def get(hub, ctx, name: str, resource_id: str) -> Dict:
 async def list_(
     hub,
     ctx,
-    name: None,
+    name: str = None,
 ) -> Dict:
     """Fetch a list of bucket from AWS that are owned by the calling user.
 
@@ -92,7 +94,7 @@ async def list_(
         return result
     for bucket in ret["ret"]["Buckets"]:
         result["ret"].append(
-            await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present(
+            await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present_async(
                 ctx=ctx, idem_resource_name=bucket["Name"]
             )
         )
