@@ -47,7 +47,9 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, name, topic_arn: str = None, resource_id: str = None) -> Dict:
+async def list_(
+    hub, ctx, name: str = None, topic_arn: str = None, resource_id: str = None
+) -> Dict:
     """Use an un-managed Subscription as a data-source.
 
     Args:
