@@ -548,26 +548,16 @@ async def present(
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif not (before and before["result"]) or are_tags_updated or is_reimported:
-            after = await hub.exec.boto3.client.acm.describe_certificate(
-                ctx, CertificateArn=resource_id
+            after = await hub.exec.aws.acm.certificate_manager.get(
+                ctx,
+                name=name,
+                resource_id=resource_id,
             )
-            if after and after.get("ret"):
-                convert_ret = (
-                    await hub.tool.aws.acm.conversion_utils.convert_raw_acm_to_present(
-                        ctx,
-                        raw_resource=after["ret"].get("Certificate"),
-                        idem_resource_name=resource_id,
-                    )
-                )
-                result["result"] = convert_ret["result"]
-                if not result["result"]:
-                    result["comment"] = result["comment"] + convert_ret["comment"]
-                result["new_state"] = convert_ret["ret"]
-            else:
-                result["result"] = result["result"] and after["result"]
-                if not result["result"]:
-                    result["comment"] = result["comment"] + after["comment"]
-                    return result
+            if not after["result"]:
+                result["result"] = False
+                result["comment"] = after["comment"]
+                return result
+            result["new_state"] = copy.deepcopy(after["ret"])
         else:
             result["new_state"] = copy.deepcopy(result["old_state"])
 
@@ -608,51 +598,35 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
             resource_type="aws.acm.certificate_manager", name=name
         )
         return result
-    before = await hub.exec.boto3.client.acm.describe_certificate(
-        ctx, CertificateArn=resource_id
+    before = await hub.exec.aws.acm.certificate_manager.get(
+        ctx=ctx, name=name, resource_id=resource_id
     )
     if not before["result"]:
-        if "ResourceNotFoundException" in str(before["comment"]):
-            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
-                resource_type="aws.acm.certificate_manager", name=name
-            )
-        else:
-            result["comment"] = before["comment"]
-            result["result"] = False
+        result["comment"] = before["comment"]
+        result["result"] = False
         return result
-    if not (before["ret"].get("Certificate")):
+    if not before["ret"]:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
             resource_type="aws.acm.certificate_manager", name=name
         )
+    elif ctx.get("test", False):
+        result["old_state"] = before["ret"]
+        result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
+            resource_type="aws.acm.certificate_manager", name=name
+        )
         return result
     else:
-        convert_ret = (
-            await hub.tool.aws.acm.conversion_utils.convert_raw_acm_to_present(
-                ctx,
-                raw_resource=before["ret"].get("Certificate"),
-                idem_resource_name=resource_id,
-            )
+        result["old_state"] = before["ret"]
+        ret = await hub.exec.boto3.client.acm.delete_certificate(
+            ctx, CertificateArn=resource_id
         )
-        result["result"] = convert_ret["result"]
+        result["result"] = ret["result"]
         if not result["result"]:
-            result["comment"] = result["comment"] + convert_ret["comment"]
-        result["old_state"] = convert_ret["ret"]
-        if ctx.get("test", False):
-            result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
-                resource_type="aws.acm.certificate_manager", name=name
-            )
+            result["comment"] = ret["comment"]
             return result
-        else:
-            ret = await hub.exec.boto3.client.acm.delete_certificate(
-                ctx, CertificateArn=resource_id
-            )
-            result["result"] = ret["result"]
-            if not result["result"]:
-                result["comment"] = ret["comment"]
-                return result
-            result["comment"] = hub.tool.aws.comment_utils.delete_comment(
-                resource_type="aws.acm.certificate_manager", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.delete_comment(
+            resource_type="aws.acm.certificate_manager", name=name
+        )
     return result
 
 
@@ -706,7 +680,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         resource = ret["ret"].get("Certificate")
 
         convert_ret = (
-            await hub.tool.aws.acm.conversion_utils.convert_raw_acm_to_present(
+            await hub.tool.aws.acm.conversion_utils.convert_raw_acm_to_present_async(
                 ctx,
                 raw_resource=resource,
                 idem_resource_name=resource_id,
