@@ -110,16 +110,14 @@ async def present(
         return result
     else:
         old_certificate = before["ret"].get("Certificate")
-
-        if ctx.get("test", False):
-            result["new_state"] = {"issued_at": "issued_time_known_after_present"}
-            result["comment"] = result["comment"] + (
-                f"Would issue AWS certificate {certificate_arn}",
-            )
-            return result
+        result["old_state"] = {
+            "certificate_arn": old_certificate.get("CertificateArn"),
+            "status": old_certificate.get("Status"),
+        }
         if old_certificate.get("Status") == ISSUED and old_certificate.get("IssuedAt"):
-            old_state = {"issued_at": old_certificate.get("IssuedAt")}
-            result["old_state"] = old_state
+            result["old_state"]["issued_at"] = old_certificate.get("IssuedAt").strftime(
+                "%m/%d/%Y %H:%M:%S"
+            )
             result["new_state"] = copy.deepcopy(result["old_state"])
             result["comment"] = (
                 f"Certificate '{certificate_arn}' issued at {old_certificate.get('IssuedAt')}",
@@ -186,7 +184,10 @@ async def present(
             ctx, CertificateArn=certificate_arn
         )
         after_certificate = after["ret"].get("Certificate")
-
+        result["new_state"] = {
+            "certificate_arn": after_certificate.get("CertificateArn"),
+            "status": after_certificate.get("Status"),
+        }
         if after_certificate.get("Status") != ISSUED:
             hub.log.debug(
                 f"Certificate '{certificate_arn}' not issued. It is in {after_certificate.get('Status')} state"
