@@ -21,30 +21,30 @@ async def present(
     Creates a new API Gateway Method Response or modifies an existing one.
 
     Args:
-        name(string):
+        name(str):
             An idem name of the resource.
 
-        rest_api_id(string):
+        rest_api_id(str):
             AWS rest_api id of the associated RestApi.
 
-        parent_resource_id(string):
+        parent_resource_id(str):
             The parent resource's id.
 
-        http_method(string):
+        http_method(str):
             String that specifies the method request's HTTP method type.
 
-        status_code(string):
+        status_code(str):
             The method response's status code.
 
-        resource_id(string, optional):
+        resource_id(str, Optional):
             Defaults to None. Idem Resource id, formatted as: rest_api_id-parent_resource_id-http_method-status_code.
 
-        response_models(dict, optional):
+        response_models(dict, Optional):
             Specifies the Model resources used for the response's content-type.
                 Response models are represented as a key/value map, with a content-type as the key and a Model name
                 as the value.
 
-        response_parameters(dict, optional):
+        response_parameters(dict, Optional):
             A key-value map specifying required or optional response parameters
                 that API Gateway can send back to the caller. A key defines a method response header and the value
                 specifies whether the associated method response header is required or not. The expression of the key
@@ -171,7 +171,7 @@ async def absent(
     name: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Deletes an API Gateway Method Response.
 
     Args:
@@ -179,10 +179,10 @@ async def absent(
 
         ctx:
 
-        name(string):
+        name(str):
             An Idem name of the resource.
 
-        resource_id(string, optional):
+        resource_id(str, Optional):
             Idem Resource id, formatted as: rest_api_id-parent_resource_id-http_method-status_code. Defaults to None.
                 Idem automatically considers this resource being absent if this field is not specified.
 
@@ -255,7 +255,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
 
     Describe the API Gateway Method Responses associated with a specific Method.
 
