@@ -93,7 +93,7 @@ async def present(
     ] = None,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Creates an AWS Budget and, if included, notifications and subscribers.
+    """Creates an AWS Budget and, if included, notifications and subscribers.
 
     Args:
         name(str):
@@ -529,7 +529,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Lists the AWS Budgets that are associated with an account.
+    """Lists the AWS Budgets that are associated with an account.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
