@@ -132,15 +132,15 @@ async def present(
                         Dimensions are also limited to LINKED_ACCOUNT, REGION, or RIGHTSIZING_TYPE. For the
                         GetReservationPurchaseRecommendation action, only NOT is supported. AND and OR aren't supported.
                         Dimensions are limited to LINKED_ACCOUNT.
-                * Or (list[dict[str, Any]], Optional):
+                * Or (list[Expression], Optional):
                     Return results that match either Dimension object.
-                        * Or (list[dict[str, Any]], Optional):
+                        * Or (list[Expression], Optional):
                             Return results that match either Dimension object.
-                        * And (list[dict[str, Any]], Optional):
+                        * And (list[Expression], Optional):
                             Return results that match both Dimension objects.
-                        * Not (dict[str, Any], Optional):
+                        * Not (Expression, Optional):
                             Return results that don't match a Dimension object.
-                        * Dimensions (dict[str, Any], Optional):
+                        * Dimensions (DimensionValues, Optional):
                             The specific Dimension to use for Expression.
                                 * Key (str, Optional):
                                     The names of the metadata types that you can use to filter and group your results. For example,
@@ -152,7 +152,7 @@ async def present(
                                     The match options that you can use to filter your results. MatchOptions is only applicable for
                                     actions related to Cost Category. The default values for MatchOptions are EQUALS and
                                     CASE_SENSITIVE.
-                        * Tags (dict[str, Any], Optional):
+                        * Tags (TagValues, Optional):
                             The specific Tag to use for Expression.
                                 * Key (str, Optional):
                                     The key for the tag.
@@ -162,7 +162,7 @@ async def present(
                                     The match options that you can use to filter your results. MatchOptions is only applicable for
                                     actions related to Cost Category. The default values for MatchOptions are EQUALS and
                                     CASE_SENSITIVE.
-                        * CostCategories (dict[str, Any], Optional):
+                        * CostCategories (CostCategoryValues, Optional):
                             The filter that's based on CostCategory values.
                                 * Key (str, Optional):
                                     The unique name of the Cost Category.
@@ -172,15 +172,15 @@ async def present(
                                     The match options that you can use to filter your results. MatchOptions is only applicable for
                                     actions related to cost category. The default values for MatchOptions is EQUALS and
                                     CASE_SENSITIVE.
-                    * And (list[dict[str, Any]], Optional):
+                    * And (list[Expression], Optional):
                         Return results that match both Dimension objects.
-                    * Not (dict[str, Any], Optional):
+                    * Not (Expression, Optional):
                         Return results that don't match a Dimension object.
-                    * Dimensions (dict[str, Any], Optional):
+                    * Dimensions (DimensionValues, Optional):
                         The specific Dimension to use for Expression.
-                    * Tags (dict[str, Any], Optional):
+                    * Tags (Any, Optional):
                         The specific Tag to use for Expression.
-                    * CostCategories (dict[str, Any], Optional):
+                    * CostCategories (Any, Optional):
                         The filter that's based on CostCategory values.
     Request Syntax:
       .. code-block:: sls
