@@ -164,7 +164,7 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""The CreateTable operation adds a new table to your account.
+    """The CreateTable operation adds a new table to your account.
 
     In an Amazon Web Services account, table names must be unique within each Region. That is, you can have two tables
     with same name if you create the tables in different Regions.  CreateTable is an asynchronous operation. Upon
@@ -648,7 +648,7 @@ async def absent(
     resource_id: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""The DeleteTable operation deletes a table and all of its items.
+    """The DeleteTable operation deletes a table and all of its items.
 
     After a DeleteTable request, the specified table is in the DELETING state until DynamoDB completes the deletion.
     If the table is in the ACTIVE state, you can delete it. If a table is in CREATING or UPDATING states, then DynamoDB
@@ -754,7 +754,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Returns:
         Dict[str, Dict[str, Any]]
