@@ -5,11 +5,13 @@ from typing import Any
 from typing import Dict
 from typing import List
 
-__contracts__ = ["resource", "soft_fail"]
+__contracts__ = ["resource", "allow_sync_sls_name_and_name_tag"]
+__reconcile_wait__ = {"static": {"wait_in_seconds": 5}}
 
 TREQ = {
     "present": {
         "require": [
+            "aws.ec2.network_interface.present",
             "aws.ec2.vpc.present",
             "aws.ec2.subnet.present",
             "aws.iam.role.present",
@@ -22,81 +24,28 @@ async def present(
     hub,
     ctx,
     name: str,
-    resource_id: str = None,
+    image_id: str,
     *,
+    resource_id: str = None,
     # From DescribeInstances
-    image_id: str = None,
     instance_type: str = None,
-    volume_attachments: Dict[str, str] = None,
     ebs_optimized: bool = None,
     kernel_id: str = None,
     subnet_id: str = None,
+    security_group_ids: List[str] = None,
     network_interfaces: List[
         make_dataclass(
-            "InstanceNetworkInterfaceSpecification",
+            "NetworkInterfaceAttachment",
             [
-                ("AssociatePublicIpAddress", bool, field(default=None)),
-                ("DeleteOnTermination", bool, field(default=None)),
-                ("Description", str, field(default=None)),
-                ("DeviceIndex", int, field(default=None)),
-                ("Groups", List[str], field(default=None)),
-                ("Ipv6AddressCount", int, field(default=None)),
-                (
-                    "Ipv6Addresses",
-                    List[
-                        make_dataclass(
-                            "InstanceIpv6Address",
-                            [("Ipv6Address", str, field(default=None))],
-                        )
-                    ],
-                    field(default=None),
-                ),
-                ("NetworkInterfaceId", str, field(default=None)),
-                ("PrivateIpAddress", str, field(default=None)),
-                (
-                    "PrivateIpAddresses",
-                    List[
-                        make_dataclass(
-                            "PrivateIpAddressSpecification",
-                            [
-                                ("Primary", bool, field(default=None)),
-                                ("PrivateIpAddress", str, field(default=None)),
-                            ],
-                        )
-                    ],
-                    field(default=None),
-                ),
-                ("SecondaryPrivateIpAddressCount", int, field(default=None)),
-                ("SubnetId", str, field(default=None)),
-                ("AssociateCarrierIpAddress", bool, field(default=None)),
-                ("InterfaceType", str, field(default=None)),
-                ("NetworkCardIndex", int, field(default=None)),
-                (
-                    "Ipv4Prefixes",
-                    List[
-                        make_dataclass(
-                            "Ipv4Prefix", [("Ipv4Prefix", str, field(default=None))]
-                        )
-                    ],
-                    field(default=None),
-                ),
-                ("Ipv4PrefixCount", int, field(default=None)),
-                (
-                    "Ipv6Prefixes",
-                    List[
-                        make_dataclass(
-                            "Ipv6Prefix", [("Ipv6Prefix", str, field(default=None))]
-                        )
-                    ],
-                    field(default=None),
-                ),
-                ("Ipv6PrefixCount", int, field(default=None)),
+                ("device_index", int),
+                ("network_interface_id", str, field(default=None)),
+                ("network_card_index", int, field(default=None)),
             ],
         )
     ] = None,
     monitoring_enabled: bool = None,
     source_dest_check: bool = None,
-    running: bool = None,
+    running: bool = True,
     private_ip_address: str = None,
     owner_id: str = None,
     # Placement Options
@@ -122,7 +71,7 @@ async def present(
         )
     ] = None,
     elastic_gpu_specifications: List[
-        make_dataclass("ElasticGpuSpecification", [("Type", str, field(default=None))])
+        make_dataclass("ElasticGpuSpecification", [("Type", str)])
     ] = None,
     auto_recovery_enabled: bool = None,
     sriov_net_support: str = None,
@@ -130,27 +79,6 @@ async def present(
     # Enclave options
     nitro_enclave_enabled: bool = None,
     # Can only be changed on initial creation of an instance as far as we know so far
-    capacity_reservation_specification: make_dataclass(
-        "CapacityReservationSpecification",
-        [
-            ("CapacityReservationPreference", str, field(default=None)),
-            (
-                "CapacityReservationTarget",
-                make_dataclass(
-                    "CapacityReservationTarget",
-                    [
-                        ("CapacityReservationId", str, field(default=None)),
-                        (
-                            "CapacityReservationResourceGroupArn",
-                            str,
-                            field(default=None),
-                        ),
-                    ],
-                ),
-                field(default=None),
-            ),
-        ],
-    ) = None,
     client_token: str = None,
     root_device_name: str = None,
     product_codes: List[Dict[str, str]] = None,
@@ -159,10 +87,9 @@ async def present(
         make_dataclass(
             "BlockDeviceMapping",
             [
-                ("DeviceName", str, field(default=None)),
-                ("VirtualName", str, field(default=None)),
-                ("Ebs", Dict, field(default=None)),
-                ("NoDevice", str, field(default=None)),
+                ("device_name", str),
+                ("volume_id", str, field(default=None)),
+                ("delete_on_termination", str, field(default=False)),
             ],
         )
     ] = None,
@@ -226,25 +153,18 @@ async def present(
             For more information, see Key pairs.
 
     Args:
-        hub:
-
-        ctx:
-
         name(str):
             An Idem name of the resource.
 
         resource_id(str):
             AWS Ec2 Instance ID.
 
-        image_id(str, Optional):
+        image_id(str):
             The ID of an AMI.
 
         instance_type(str, Optional):
             The instance type to use for this instance on creation.
 
-        volume_attachments(dict[str, str], Optional):
-            The instance device name mapped to a volume id.
-
         ebs_optimized(bool, Optional):
             Indicates whether the instance is optimized ofr Amazon EBS I/O.
 
@@ -254,116 +174,30 @@ async def present(
         subnet_id(str, Optional):
             The ID of the subnet in which the instance is running.
 
+        security_group_ids(List[str], Optional):
+            The IDs of the security groups. If you specify a network interface, you must specify any security
+            groups as part of the network interface. Default: Amazon EC2 uses the default security group.
+
         network_interfaces(list[dict[str, Any]], Optional):
-            The network interfaces to associate with the instance. If you specify a network interface, you must specify
-            any security groups and subnets as part of the network interface. Defaults to None.
+            The network interfaces to associate with the instance. This manages the network interface attachment
+            to the instance, network interfaces themselves are managed in a separate state. Defaults to None.
 
-            * AssociatePublicIpAddress (bool, Optional):
-                Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public
-                IP address can only be assigned to a network interface for eth0, and can only be assigned to a
-                new network interface, not an existing one. You cannot specify more than one network interface
-                in the request. If launching into a default subnet, the default value is true.
+            * network_interface_id (str, Optional):
+                The ID of the network interface. If you are creating a Spot Fleet, omit this parameter because
+                you can’t specify a network interface ID in a launch specification.
 
-            * DeleteOnTermination (bool, Optional):
-                If set to true, the interface is deleted when the instance is terminated. You can specify true only if
-                creating a new network interface when launching an instance.
-
-            * Description (str, Optional):
-                The description of the network interface. Applies only if creating a network interface when launching
-                an instance.
-
-            * DeviceIndex (int, Optional):
+            * device_index (int, Optional):
                 The position of the network interface in the attachment order. A primary network interface has a
                 device index of 0. If you specify a network interface when launching an instance, you must
                 specify the device index.
 
-            * Groups (list[str], Optional):
-                The IDs of the security groups for the network interface. Applies only if creating a network
-                interface when launching an instance.
-
-            * Ipv6AddressCount (int, Optional):
-                A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6
-                addresses from the range of the subnet. You cannot specify this option and the option to assign
-                specific IPv6 addresses in the same request. You can specify this option if you've specified a
-                minimum number of instances to launch.
-
-            * Ipv6Addresses (list[dict[str, Any]], Optional):
-                One or more IPv6 addresses to assign to the network interface. You cannot specify this option
-                and the option to assign a number of IPv6 addresses in the same request. You cannot specify this
-                option if you've specified a minimum number of instances to launch.
-
-                * Ipv6Address (str, Optional):
-                    The IPv6 address.
-
-            * NetworkInterfaceId (str, Optional):
-                The ID of the network interface. If you are creating a Spot Fleet, omit this parameter because
-                you can’t specify a network interface ID in a launch specification.
-
-            * PrivateIpAddress (str, Optional):
-                The private IPv4 address of the network interface. Applies only if creating a network interface
-                when launching an instance. You cannot specify this option if you're launching more than one
-                instance in a RunInstances request.
-
-            * PrivateIpAddresses (list[dict[str, Any]], Optional):
-                One or more private IPv4 addresses to assign to the network interface. Only one private IPv4
-                address can be designated as primary. You cannot specify this option if you're launching more
-                than one instance in a RunInstances request.
-
-                * Primary (bool, Optional):
-                    Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4
-                    address can be designated as primary.
-
-                * PrivateIpAddress (str, Optional):
-                    The private IPv4 addresses.
-
-            * SecondaryPrivateIpAddressCount (int, Optional):
-                The number of secondary private IPv4 addresses. You can't specify this option and specify more
-                than one private IP address using the private IP addresses option. You cannot specify this
-                option if you're launching more than one instance in a RunInstances request.
-
-            * SubnetId (str, Optional):
-                The ID of the subnet associated with the network interface. Applies only if creating a network
-                interface when launching an instance.
-
-            * AssociateCarrierIpAddress (bool, Optional):
-                Indicates whether to assign a carrier IP address to the network interface. You can only assign a
-                carrier IP address to a network interface that is in a subnet in a Wavelength Zone. For more
-                information about carrier IP addresses, see Carrier IP addresses in the Amazon Web Services
-                Wavelength Developer Guide.
-
-            * InterfaceType (str, Optional):
-                The type of network interface. Valid values: interface | efa.
-
-            * NetworkCardIndex (int, Optional):
+            * network_card_index (int, Optional):
                 The index of the network card. Some instance types support multiple network cards. The primary
                 network interface must be assigned to network card index 0. The default is network card index 0.
                 If you are using RequestSpotInstances to create Spot Instances, omit this parameter because you
                 can’t specify the network card index when using this API. To specify the network card index, use
                 RunInstances.
 
-            * Ipv4Prefixes (list[dict[str, Any]], Optional):
-                One or more IPv4 delegated prefixes to be assigned to the network interface. You cannot use this
-                option if you use the Ipv4PrefixCount option.
-
-                * Ipv4Prefix (str, Optional):
-                    The IPv4 prefix. For information, see  Assigning prefixes to Amazon EC2 network interfaces in
-                    the Amazon Elastic Compute Cloud User Guide.
-
-            * Ipv4PrefixCount (int, Optional):
-                The number of IPv4 delegated prefixes to be automatically assigned to the network interface. You
-                cannot use this option if you use the Ipv4Prefix option.
-
-            * Ipv6Prefixes (list[dict[str, Any]], Optional):
-                One or more IPv6 delegated prefixes to be assigned to the network interface. You cannot use this
-                option if you use the Ipv6PrefixCount option.
-
-                * Ipv6Prefix (str, Optional):
-                    The IPv6 prefix.
-
-            * Ipv6PrefixCount (int, Optional):
-                The number of IPv6 delegated prefixes to be automatically assigned to the network interface. You
-                cannot use this option if you use the Ipv6Prefix option.
-
         monitoring_enabled(bool, Optional):
             Indicates whether detailed monitoring is enabled.
 
@@ -455,32 +289,6 @@ async def present(
         nitro_enclave_enabled(bool, Optional):
             Indicates whether the instance is enabled for AWS Nitro Enclaves.
 
-        capacity_reservation_specification(dict[str, Any], Optional):
-            Information about the Capacity Reservation targeting option. If you do not specify this
-            parameter, the instance's Capacity Reservation preference defaults to open, which enables it to
-            run in any open Capacity Reservation that has matching attributes (instance type, platform,
-            Availability Zone). Defaults to None.
-
-            * CapacityReservationPreference (str, Optional):
-                Indicates the instance's Capacity Reservation preferences.
-                Possible preferences include:
-
-                * open:
-                    The instance can run in any open Capacity Reservation that has matching attributes (instance
-                    type, platform, Availability Zone).
-
-                * none:
-                    The instance avoids running in a Capacity Reservation even if one is available. The instance runs as an On-Demand Instance.
-
-            * CapacityReservationTarget (dict[str, Any], Optional):
-                Information about the target Capacity Reservation or Capacity Reservation group.
-
-                * CapacityReservationId (str, Optional):
-                    The ID of the Capacity Reservation in which to run the instance.
-
-                * CapacityReservationResourceGroupArn (str, Optional):
-                    The ARN of the Capacity Reservation resource group in which to run the instance.
-
         client_token(str, Optional):
             The idempotency token for the instance.
 
@@ -498,10 +306,13 @@ async def present(
             the instance at launch. For more information, see Block device mappings in the Amazon EC2 User
             Guide. Defaults to None.
 
-            * DeviceName (str, Optional):
+            * device_name (str, Optional):
                 The device name (for example, /dev/sdh or xvdh).
 
-            * VirtualName (str, Optional):
+            * volume_id: (str):
+                The resource_id of the volume to attach to the instance.
+
+            * virtual_name (str, Optional):
                 The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An
                 instance type with 2 available instance store volumes can specify mappings for ephemeral0 and
                 ephemeral1. The number of available instance store volumes depends on the instance type. After
@@ -511,61 +322,9 @@ async def present(
                 block device mapping for the instance. When you launch an M3 instance, we ignore any instance
                 store volumes specified in the block device mapping for the AMI.
 
-            * Ebs (dict[str, Any], Optional):
-                Parameters used to automatically set up EBS volumes when the instance is launched.
-
-                * DeleteOnTermination (bool, Optional):
-                    Indicates whether the EBS volume is deleted on instance termination. For more information, see
-                    Preserving Amazon EBS volumes on instance termination in the Amazon EC2 User Guide.
-
-                * Iops (int, Optional): The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes,
-                    this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this
-                    represents the baseline performance of the volume and the rate at which the volume accumulates I/O
-                    credits for bursting. The following are the supported values for each volume type:
-                    gp3: 3,000-16,000 IOPS    io1: 100-64,000 IOPS    io2: 100-64,000 IOPS   For io1 and io2 volumes,
-                    we guarantee 64,000 IOPS only for Instances built on the Nitro System. Other instance families
-                    guarantee performance up to 32,000 IOPS. This parameter is required for io1 and io2 volumes.
-                    The default for gp3 volumes is 3,000 IOPS. This parameter is not supported for gp2, st1, sc1, or
-                    standard volumes.
-
-                * SnapshotId (str, Optional):
-                    The ID of the snapshot.
-
-                * VolumeSize (int, Optional):
-                    The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you
-                    specify a snapshot, the default is the snapshot size. You can specify a volume size that is
-                    equal to or larger than the snapshot size. The following are the supported volumes sizes for
-                    each volume type:    gp2 and gp3:1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384
-                    standard: 1-1,024.
-
-                * VolumeType (str, Optional):
-                    The volume type. For more information, see Amazon EBS volume types in the Amazon EC2 User Guide.
-                    If the volume type is io1 or io2, you must specify the IOPS that the volume supports.
-
-                * KmsKeyId (str, Optional):
-                    Identifier (key ID, key alias, ID ARN, or alias ARN) for a customer managed CMK under which the
-                    EBS volume is encrypted. This parameter is only supported on BlockDeviceMapping objects called
-                    by RunInstances, RequestSpotFleet, and RequestSpotInstances.
-
-                * Throughput (int, Optional):
-                    The throughput that the volume supports, in MiB/s. This parameter is valid only for gp3 volumes.
-                    Valid Range: Minimum value of 125. Maximum value of 1000.
-
-                * OutpostArn (str, Optional):
-                    The ARN of the Outpost on which the snapshot is stored. This parameter is only supported on
-                    BlockDeviceMapping objects called by  CreateImage.
-
-                * Encrypted (bool, Optional):
-                    Indicates whether the encryption state of an EBS volume is changed while being restored from a
-                    backing snapshot. The effect of setting the encryption state to true depends on the volume
-                    origin (new or from a snapshot), starting encryption state, ownership, and whether encryption by
-                    default is enabled. For more information, see Amazon EBS encryption in the Amazon EC2 User
-                    Guide. In no case can you remove encryption from an encrypted volume. Encrypted volumes can only
-                    be attached to instances that support Amazon EBS encryption. For more information, see Supported
-                    instance types. This parameter is not returned by DescribeImageAttribute.
-
-            * NoDevice (str, Optional): To omit the device from the block device mapping, specify an empty string. When this property is
-                specified, the device is removed from the block device mapping regardless of the assigned value.
+            * delete_on_termination (bool, Optional):
+                Indicates whether the EBS volume is deleted on instance termination. For more information, see
+                Preserving Amazon EBS volumes on instance termination in the Amazon EC2 User Guide.
 
         license_arns(list[str], Optional):
             The license configuration arns.
@@ -728,17 +487,24 @@ async def present(
                         values:
                           - x86_64
 
+            my_network_interface:
+              aws.ec2.network_interface.present:
+                - subnet_id: ${exec:default_subnet:resource_id}
+
             create_instance:
               aws.ec2.instance.present:
                 - subnet_id: ${exec:default_subnet:resource_id}
                 - image_id: ${exec:small_image:resource_id}
                 - instance_type: ${exec:small_instance_type:resource_id}
                 - client_token: optional-idempotence-token
+                - network_interfaces:
+                  - network_interface_id: ${aws.ec2.network_interface:my_network_interface:resource_id}
+                    device_index: 123
+                    network_card_index: 123
                 - tags:
                     Name: test-idem-cloud-demo
                 - bootstrap:
-                    heist_manager: salt.minion
-                    auto_configure: True
+                  - heist_manager: salt.minion
     """
     # Convert a list of dictionaries to a plain dictionary before calculating desired_state
     if isinstance(tags, list):
@@ -753,10 +519,6 @@ async def present(
 
     result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
 
-    # Get the resource_id from ESM
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get("resource_id")
-
     current_state = None
     if resource_id:
         get = await hub.exec.aws.ec2.instance.get(
@@ -776,15 +538,15 @@ async def present(
             ctx, name=name, filters=[{"Name": "client-token", "Values": [client_token]}]
         )
 
-        current_state = result["old_state"] = get.ret
-        if not result["old_state"]:
-            result["comment"] += [
-                f"Could not find instance for '{name}' with existing idempotence token '{client_token}'"
-            ]
-
-        else:
-            resource_id = current_state.resource_id
-            result["comment"] += [f"Instance '{name}' already exists"]
+        if get.result is True:
+            if get.ret is None:
+                result["comment"] += [
+                    f"Could not find Instance for '{name}' with existing idempotence token '{client_token}'"
+                ]
+            else:
+                current_state = result["old_state"] = get.ret
+                resource_id = current_state.resource_id
+                result["comment"] += [f"Instance '{name}' already exists"]
 
     if not resource_id:
         if ctx.test:
@@ -921,6 +683,40 @@ async def present(
                 "CapacityReservationPreference"
             ] = capacity_reservation_preference
 
+        network_interface_attachment_specification = []
+        if subnet_id:
+            # Subnet id and network interfaces cannot be specified together
+            # The network interfaces will be handled in the update process
+            network_interface_attachment_specification = None
+        elif network_interfaces:
+            for network_interface_attachment in network_interfaces:
+                network_interface_attachment_specification.append(
+                    {
+                        "NetworkInterfaceId": network_interface_attachment.get(
+                            "network_interface_id"
+                        ),
+                        "DeviceIndex": network_interface_attachment.get("device_index"),
+                        "NetworkCardIndex": network_interface_attachment.get(
+                            "network_card_index"
+                        ),
+                    }
+                )
+
+        new_block_device_mappings = None
+        if block_device_mappings:
+            new_block_device_mappings = list()
+            for bd in block_device_mappings:
+                device_name = bd.get("device_name")
+                if not device_name:
+                    continue
+                # Create an empty mapping while the instance is starting -- it will be connected on update
+                new_bd = dict(DeviceName=device_name, NoDevice="")
+                if bd.get("virtual_name"):
+                    new_bd["VirtualName"] = bd["virtual_name"]
+                if bd.get("delete_on_termination"):
+                    new_bd["DeleteOnTermination"] = bd["delete_on_termination"]
+                new_block_device_mappings.append(new_bd)
+
         # Create a brand new instance with minimal arguments, it will be updated after creation
         create_ret = await hub.exec.boto3.client.ec2.run_instances(
             ctx,
@@ -929,12 +725,12 @@ async def present(
             MinCount=1,
             ImageId=image_id,
             InstanceType=instance_type,
-            BlockDeviceMappings=block_device_mappings,
             EbsOptimized=ebs_optimized,
+            BlockDeviceMappings=new_block_device_mappings,
             KernelId=kernel_id,
             Placement=placement or None,
             SubnetId=subnet_id,
-            NetworkInterfaces=network_interfaces,
+            NetworkInterfaces=network_interface_attachment_specification,
             Monitoring=monitoring_options or None,
             PrivateIpAddress=private_ip_address,
             UserData=user_data,
@@ -943,7 +739,7 @@ async def present(
             EnclaveOptions=enclave_options or None,
             RamDiskId=ram_disk_id,
             TagSpecifications=tag_specifications,
-            ElasticGpuSpecifications=elastic_gpu_specifications,
+            ElasticGpuSpecification=elastic_gpu_specifications,
             ElasticInferenceAccelerators=elastic_inference_accelerators,
             IamInstanceProfile={"Arn": iam_instance_profile_arn}
             if iam_instance_profile_arn
@@ -961,6 +757,7 @@ async def present(
             MetadataOptions=metadata_options or None,
             PrivateDnsNameOptions=private_dns_name_options or None,
             MaintenanceOptions=maintenance_options or None,
+            SecurityGroupIds=security_group_ids,
         )
 
         result["result"] &= create_ret.result
@@ -974,8 +771,10 @@ async def present(
         result["new_state"] = dict(name=name, resource_id=resource_id)
         result["force_save"] = True
 
-        present_ret = await hub.tool.aws.ec2.instance.state.convert_to_present(
-            ctx, {"Reservations": [create_ret.ret]}, name=name
+        present_ret = (
+            await hub.tool.aws.ec2.instance.state.convert_instance_to_present_async(
+                ctx, {"Reservations": [create_ret.ret]}, name=name
+            )
         )
         current_state = present_ret[resource_id]
 
@@ -988,16 +787,16 @@ async def present(
 
     # Modify all the attributes that need modification
     if ctx.test:
+        if running:
+            desired_state["instance_state"] = "running"
+        else:
+            desired_state["instance_state"] = "stopped"
+
         result["new_state"] = hub.tool.aws.ec2.instance.state.test(**desired_state)
     else:
         resource = await hub.tool.boto3.resource.create(
             ctx, "ec2", "Instance", id=resource_id
         )
-        hub.log.debug(f"Waiting for instance '{resource.id}' to be created")
-        try:
-            await hub.tool.boto3.resource.exec(resource, "wait_until_exists")
-        except:
-            ...
         result["result"] &= await hub.tool.aws.ec2.instance.update.init.apply(
             ctx,
             resource,
@@ -1009,7 +808,16 @@ async def present(
         get = await hub.exec.aws.ec2.instance.get(
             ctx, resource_id=resource_id, name=name
         )
-        result["new_state"] = get.ret
+        current_state = get.ret
+        result["new_state"] = current_state
+
+        if running:
+            # If running is set to True then it goes to reconciler and makes sure current state is running
+            hub.log.debug(f"Waiting for instance '{resource_id}' to be running")
+            result["rerun_data"] = dict(target_instance_state="running")
+        else:
+            hub.log.debug(f"Waiting for instance '{resource_id}' to be stopped")
+            result["rerun_data"] = dict(target_instance_state="stopped")
 
     return result
 
@@ -1045,7 +853,12 @@ async def absent(
                 - name: value
     """
     result = dict(
-        comment=[], old_state=ctx.old_state, new_state=None, name=name, result=True
+        comment=[],
+        old_state=ctx.old_state,
+        new_state=None,
+        name=name,
+        result=True,
+        rerun_data=dict(target_instance_state="terminated"),
     )
 
     # Get the resource_id from ESM
@@ -1070,6 +883,7 @@ async def absent(
     ret = await hub.exec.boto3.client.ec2.terminate_instances(
         ctx, InstanceIds=[resource_id]
     )
+
     if ret.comment:
         result["comment"].append(ret.comment)
 
@@ -1080,9 +894,14 @@ async def absent(
         # The failure is some other reason we need to examine
         result["result"] &= ret.result
     else:
+        get = await hub.exec.aws.ec2.instance.get(
+            ctx, resource_id=resource_id, name=name
+        )
+        result["new_state"] = get.ret
         result["comment"] += [
             f"Terminated instance '{name}', it will still be visible for about 60 minutes"
         ]
+
     return result
 
 
@@ -1104,7 +923,9 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         hub.log.debug(f"Could not describe Instances: {ret.comment}")
         return {}
 
-    instances = await hub.tool.aws.ec2.instance.state.convert_to_present(ctx, ret.ret)
+    instances = await hub.tool.aws.ec2.instance.state.convert_instance_to_present_async(
+        ctx, ret.ret
+    )
 
     for instance_id, present_state in instances.items():
         result[instance_id] = {
@@ -1112,3 +933,23 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
+
+
+def is_pending(hub, ret):
+    new_state = ret.get("new_state", None)
+    rerun_data = ret.get("rerun_data", None)
+    if new_state and rerun_data:
+        current_status = new_state.get("instance_state")
+        resource_id = new_state.get("resource_id")
+        if current_status and isinstance(current_status, str):
+            if current_status.casefold() == rerun_data.get("target_instance_state"):
+                hub.log.debug(
+                    f"No need to reconcile new state for instance '{resource_id}' with current status {current_status}"
+                )
+                return False
+            else:
+                hub.log.debug(
+                    f"Reconcile new state for instance '{resource_id}' with current status {current_status}"
+                )
+                return True
+    return (not ret["result"]) or bool(ret["changes"])
