@@ -40,7 +40,7 @@ async def present(
     ] = None,
     description: str = None,
 ) -> Dict[str, Any]:
-    r"""Creates a security group rule.
+    """Creates a security group rule.
 
     Adds the specified inbound (ingress) or outbound (egress) rules to a security group:
         * An inbound rule permits instances to receive traffic from the specified IPv4 or IPv6 CIDR address range, or from the
