@@ -741,8 +741,8 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         hub.log.debug(f"Could not describe spot instance requests: {ret.comment}")
         return {}
 
-    spot_instance_requests = (
-        await hub.tool.aws.ec2.spot_instance_request.convert_to_present(ret.ret)
+    spot_instance_requests = hub.tool.aws.ec2.spot_instance_request.convert_to_present(
+        ret.ret
     )
 
     for resource_id, present_state in spot_instance_requests.items():
