@@ -473,66 +473,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             ]
         }
     return result
-
-
-async def search(
-    hub,
-    ctx,
-    name,
-    resource_id: str = None,
-    availability_zone: str = None,
-    availability_zone_id: str = None,
-    cidr_block: str = None,
-    default_for_az: str = None,
-    filters: List = None,
-    ipv6_cidr_block: str = None,
-    status: str = None,
-    vpc_id: str = None,
-    tags: List[Dict[str, Any]] or Dict[str, Any] = None,
-):
-    """
-    Use an un-managed subnet as a data-source. Supply one of the inputs as the filter. This function has been deprecated.
-    Please use exec.run with aws.ec2.subnet.get instead.
-
-    Args:
-        name(str): The name of the Idem state.
-        resource_id(str, Optional): AWS subnet id to identify the resource.
-        availability_zone(str, Optional): The Availability Zone for the subnet.
-        availability_zone_id(str, Optional): The ID of the Availability Zone for the subnet.
-        cidr_block(str, Optional): The IPv4 CIDR block of the subnet. The CIDR block you specify must exactly match
-         the subnet's CIDR block for information to be returned for the subnet.
-        default_for_az(str, Optional): Indicate whether the subnet is the default subnet in the Availability Zone.
-        filters(List, Optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_subnets
-        ipv6_cidr_block(str, Optional): An IPv6 CIDR block associated with the subnet.
-        status(str, Optional): The state of the subnet (pending | available ).
-        vpc_id(str, Optional): The ID of the VPC for the subnet.
-        tags(List or Dict, Optional): The list or dict of tags to filter by.
-
-    """
-    hub.log.warning(
-        f"aws.ec2.subnet.search '{name}' state has been deprecated. Please use exec.run with aws.ec2.subnet.get instead."
-    )
-
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
-    ret = await hub.exec.aws.ec2.subnet.get(
-        ctx=ctx,
-        name=name,
-        resource_id=resource_id,
-        availability_zone=availability_zone,
-        availability_zone_id=availability_zone_id,
-        cidr_block=cidr_block,
-        default_for_az=default_for_az,
-        filters=filters,
-        ipv6_cidr_block=ipv6_cidr_block,
-        status=status,
-        vpc_id=vpc_id,
-        tags=tags,
-    )
-    result["result"] = ret["result"]
-    result["comment"] = ret["comment"]
-    if result["result"] and ret["ret"]:
-        result["old_state"] = ret["ret"]
-        # Populate both "old_state" and "new_state" with the same data
-        result["new_state"] = copy.deepcopy(result["old_state"])
-    return result
