@@ -57,7 +57,7 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""Creates a VPC endpoint for a specified service.
+    """Creates a VPC endpoint for a specified service.
 
     An endpoint enables you to create a private connection between your VPC and the service. The service may be provided
     by Amazon Web Services, an Amazon Web Services Marketplace Partner, or another Amazon Web Services account. For more
@@ -319,7 +319,7 @@ async def present(
 async def absent(
     hub, ctx, name: str, resource_id: str = None, timeout: Dict = None
 ) -> Dict[str, Any]:
-    r"""
+    """
     Deletes the specified VPC endpoint.
 
     You can delete any of the following types of VPC endpoints. Gateway endpoint,   Gateway Load Balancer endpoint,
@@ -462,7 +462,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Describes one or more of your VPC endpoints.
@@ -486,6 +486,9 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     for resource in ret["ret"]:
         result[resource.get("resource_id")] = {
-            "aws.ec2.vpc_endpoint.present": [resource]
+            "aws.ec2.vpc_endpoint.present": [
+                {parameter_key: parameter_value}
+                for parameter_key, parameter_value in resource.items()
+            ]
         }
     return result
