@@ -37,32 +37,32 @@ async def present(
             An identifier of the resource in the provider. It is an identifier of the
             vpc peering connection of which the options are part of.
 
-        peer_allow_remote_vpc_dns_resolution(bool, optional):
+        peer_allow_remote_vpc_dns_resolution(bool, Optional):
             VPC peering connection option for the accepter:
             Requester Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses
             when queried from instances in a peer VPC.
 
-        peer_allow_classic_link_to_remote_vpc(bool, optional):
+        peer_allow_classic_link_to_remote_vpc(bool, Optional):
             VPC peering connection option for the accepter:
             Indicates whether a local ClassicLink connection can communicate with the peer VPC
             over the VPC peering connection.
 
-        peer_allow_vpc_to_remote_classic_link(bool, optional):
+        peer_allow_vpc_to_remote_classic_link(bool, Optional):
             VPC peering connection option for the accepter:
             Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC
             over the VPC peering connection.
 
-        allow_remote_vpc_dns_resolution(bool, optional):
+        allow_remote_vpc_dns_resolution(bool, Optional):
             VPC peering connection option for the requester:
             Requester Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses
             when queried from instances in a peer VPC.
 
-        allow_classic_link_to_remote_vpc(bool, optional):
+        allow_classic_link_to_remote_vpc(bool, Optional):
             VPC peering connection option for the requester:
             Indicates whether a local ClassicLink connection can communicate with the peer VPC
             over the VPC peering connection.
 
-        allow_vpc_to_remote_classic_link(bool, optional):
+        allow_vpc_to_remote_classic_link(bool, Optional):
             VPC peering connection option for the requester:
             Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC
             over the VPC peering connection.
