@@ -112,8 +112,8 @@ async def present(
         ],
     ) = None,
     client_request_token: str = None,
-    outpost_config: (
-        "outpostConfig",
+    outpost_config: make_dataclass(
+        "OutpostConfig",
         [
             (
                 "outpostArns",
