@@ -632,7 +632,6 @@ async def present(
                 snapshot_retention_limit=snapshot_retention_limit,
                 snapshot_window=snapshot_window,
                 cache_node_type=cache_node_type,
-                auth_token=auth_token,
                 auto_token_update_strategy=auto_token_update_strategy,
                 user_group_ids_to_add=user_group_ids_to_add,
                 user_group_ids_to_remove=user_group_ids_to_remove,
@@ -985,7 +984,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             )
             continue
         resource["Tags"] = tag_ret["ret"].get("TagList", [])
-        resource_translated = await hub.tool.aws.elasticache.conversion_utils.convert_raw_elasticache_replication_group_to_present(
+        resource_translated = await hub.tool.aws.elasticache.conversion_utils.convert_raw_elasticache_replication_group_to_present_async(
             ctx=ctx,
             raw_resource=resource,
             idem_resource_name=resource_id,
