@@ -194,7 +194,7 @@ async def present(
                 - scheme: internal
 
     """
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
+    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     plan_state = {}
     before = None
     resource_updated = False
@@ -204,7 +204,7 @@ async def present(
         )
         if not before["result"] or not before["ret"]:
             result["result"] = False
-            result["comment"] = before["comment"]
+            result["comment"] = tuple(before["comment"])
             return result
         result["old_state"] = copy.deepcopy(before["ret"])
         plan_state = copy.deepcopy(result["old_state"])
@@ -227,23 +227,22 @@ async def present(
             plan_state=plan_state,
             resource_id=resource_id,
         )
-        result["comment"] = update_return["comment"]
+        result["comment"] = tuple(update_return["comment"])
         if not update_return["result"]:
             result["result"] = False
             return result
         resource_updated = bool(update_return["ret"])
         if resource_updated:
+            if update_return["ret"] is not None:
+                for updated_value in update_return["ret"]:
+                    plan_state[updated_value.get("Key")] = updated_value.get("Value")
             if ctx.get("test", False):
-                result["comment"] += list(
-                    hub.tool.aws.comment_utils.would_update_comment(
-                        resource_type="aws.elbv2.load_balancer", name=name
-                    )
+                result["comment"] += hub.tool.aws.comment_utils.would_update_comment(
+                    resource_type="aws.elbv2.load_balancer", name=name
                 )
             else:
-                result["comment"] += list(
-                    hub.tool.aws.comment_utils.update_comment(
-                        resource_type="aws.elbv2.load_balancer", name=name
-                    )
+                result["comment"] += hub.tool.aws.comment_utils.update_comment(
+                    resource_type="aws.elbv2.load_balancer", name=name
                 )
 
         if tags is not None and tags != result["old_state"].get("tags"):
@@ -251,10 +250,10 @@ async def present(
             update_tags = await hub.tool.aws.elbv2.tag.update(
                 ctx=ctx,
                 resource_id=resource_id,
-                old_tags=result["old_state"]["tags"],
+                old_tags=result["old_state"].get("tags"),
                 new_tags=tags,
             )
-            result["comment"] += list(update_tags["comment"])
+            result["comment"] += update_tags["comment"]
             result["result"] = update_tags["result"]
             resource_updated = resource_updated or bool(update_tags["ret"])
             if ctx.get("test", False) and update_tags["ret"]:
@@ -276,10 +275,8 @@ async def present(
                     "attributes": attributes,
                 },
             )
-            result["comment"] = list(
-                hub.tool.aws.comment_utils.would_create_comment(
-                    resource_type="aws.elbv2.load_balancer", name=name
-                )
+            result["comment"] = hub.tool.aws.comment_utils.would_create_comment(
+                resource_type="aws.elbv2.load_balancer", name=name
             )
             return result
         ret = await hub.exec.boto3.client.elbv2.create_load_balancer(
@@ -295,14 +292,12 @@ async def present(
             CustomerOwnedIpv4Pool=customer_owned_ipv4_pool,
         )
         if not ret["result"] and not ret["ret"]:
-            result["comment"] = list(ret["comment"])
+            result["comment"] = ret["comment"]
             result["result"] = False
             return result
         resource_id = (ret["ret"]["LoadBalancers"][0]).get("LoadBalancerArn")
-        result["comment"] = list(
-            hub.tool.aws.comment_utils.create_comment(
-                resource_type="aws.elbv2.load_balancer", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.create_comment(
+            resource_type="aws.elbv2.load_balancer", name=name
         )
         if attributes:
             attributes_update = (
@@ -313,10 +308,10 @@ async def present(
                 )
             )
             if not attributes_update["result"]:
-                result["comment"] += list(attributes_update["comment"])
+                result["comment"] += attributes_update["comment"]
                 result["result"] = False
                 return result
-            result["comment"].append("Modified Attributes.")
+            result["comment"] += ("Modified Attributes.",)
 
     if ctx.get("test", False):
         result["new_state"] = plan_state
@@ -366,12 +361,10 @@ async def absent(
               - resource_id: arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/my-load-balancer/50dc6c495c0c9188
 
     """
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
+    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     if not resource_id:
-        result["comment"] = list(
-            hub.tool.aws.comment_utils.already_absent_comment(
-                resource_type="aws.elbv2.load_balancer", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.elbv2.load_balancer", name=name
         )
         return result
     before = await hub.exec.aws.elbv2.load_balancer.get(
@@ -383,18 +376,14 @@ async def absent(
         return result
 
     if not before["ret"]:
-        result["comment"] = list(
-            hub.tool.aws.comment_utils.already_absent_comment(
-                resource_type="aws.elbv2.load_balancer", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.elbv2.load_balancer", name=name
         )
     else:
         result["old_state"] = before["ret"]
         if ctx.get("test", False):
-            result["comment"] = list(
-                hub.tool.aws.comment_utils.would_delete_comment(
-                    resource_type="aws.elbv2.load_balancer", name=name
-                )
+            result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
+                resource_type="aws.elbv2.load_balancer", name=name
             )
             return result
         else:
@@ -402,13 +391,11 @@ async def absent(
                 ctx, LoadBalancerArn=resource_id
             )
             if not ret["result"]:
-                result["comment"] += list(ret["comment"])
+                result["comment"] += ret["comment"]
                 result["result"] = False
                 return result
-            result["comment"] = list(
-                hub.tool.aws.comment_utils.delete_comment(
-                    resource_type="aws.elbv2.load_balancer", name=name
-                )
+            result["comment"] = hub.tool.aws.comment_utils.delete_comment(
+                resource_type="aws.elbv2.load_balancer", name=name
             )
     return result
 
