@@ -267,7 +267,7 @@ async def present(
             - resource_id: arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targets/73e2d6bc24d8a067
 
     """
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
+    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     plan_state = {}
     before = None
     resource_updated = False
@@ -277,7 +277,7 @@ async def present(
         )
         if not before["result"] or not before["ret"]:
             result["result"] = False
-            result["comment"] = before["comment"]
+            result["comment"] = tuple(before["comment"])
             return result
         result["old_state"] = copy.deepcopy(before["ret"])
         plan_state = copy.deepcopy(result["old_state"])
@@ -309,27 +309,34 @@ async def present(
             plan_state=plan_state,
             resource_id=resource_id,
         )
-        result["comment"] = update_return["comment"]
+        result["comment"] = tuple(update_return["comment"])
         if not update_return["result"]:
             result["result"] = False
             return result
         resource_updated = bool(update_return["ret"])
-        if resource_updated and ctx.get("test", False):
-            result["comment"] += list(
-                hub.tool.aws.comment_utils.would_update_comment(
+        if resource_updated:
+            if update_return["ret"] is not None:
+                for updated_value in update_return["ret"]:
+                    plan_state[updated_value.get("Key")] = updated_value.get("Value")
+            if ctx.get("test", False):
+                result["comment"] += hub.tool.aws.comment_utils.would_update_comment(
+                    resource_type="aws.elbv2.target_group", name=name
+                )
+
+            else:
+                result["comment"] += hub.tool.aws.comment_utils.update_comment(
                     resource_type="aws.elbv2.target_group", name=name
                 )
-            )
 
         if tags is not None and tags != result["old_state"].get("tags"):
             # Update tags
             update_tags = await hub.tool.aws.elbv2.tag.update(
                 ctx=ctx,
                 resource_id=resource_id,
-                old_tags=result["old_state"]["tags"],
+                old_tags=result["old_state"].get("tags"),
                 new_tags=tags,
             )
-            result["comment"] += list(update_tags["comment"])
+            result["comment"] += update_tags["comment"]
             result["result"] = update_tags["result"]
             resource_updated = resource_updated or bool(update_tags["ret"])
             if ctx.get("test", False) and update_tags["ret"]:
@@ -361,10 +368,8 @@ async def present(
                     "ip_address_type": ip_address_type,
                 },
             )
-            result["comment"] = list(
-                hub.tool.aws.comment_utils.would_create_comment(
-                    resource_type="aws.elbv2.target_group", name=name
-                )
+            result["comment"] = hub.tool.aws.comment_utils.would_create_comment(
+                resource_type="aws.elbv2.target_group", name=name
             )
             return result
         ret = await hub.exec.boto3.client.elbv2.create_target_group(
@@ -388,14 +393,12 @@ async def present(
             IpAddressType=ip_address_type,
         )
         if not ret["result"]:
-            result["comment"] = list(ret["comment"])
+            result["comment"] = ret["comment"]
             result["result"] = False
             return result
         resource_id = (ret["ret"]["TargetGroups"][0]).get("TargetGroupArn")
-        result["comment"] = list(
-            hub.tool.aws.comment_utils.create_comment(
-                resource_type="aws.elbv2.target_group", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.create_comment(
+            resource_type="aws.elbv2.target_group", name=name
         )
         if targets:
             register_targets = await hub.exec.boto3.client.elbv2.register_targets(
@@ -404,10 +407,10 @@ async def present(
                 Targets=targets,
             )
             if not register_targets["result"]:
-                result["comment"] += list(register_targets["comment"])
+                result["comment"] += register_targets["comment"]
                 result["result"] = False
                 return result
-            result["comment"].append("Registered Targets.")
+            result["comment"] += ("Registered Targets.",)
         if attributes:
             modify_attributes = (
                 await hub.exec.boto3.client.elbv2.modify_target_group_attributes(
@@ -417,10 +420,10 @@ async def present(
                 )
             )
             if not modify_attributes["result"]:
-                result["comment"] += list(modify_attributes["comment"])
+                result["comment"] += modify_attributes["comment"]
                 result["result"] = False
                 return result
-            result["comment"].append("Added Attributes.")
+            result["comment"] += ("Added Attributes.",)
 
     if ctx.get("test", False):
         result["new_state"] = plan_state
@@ -430,7 +433,7 @@ async def present(
         )
         if not after["result"] or not after["ret"]:
             result["result"] = False
-            result["comment"] += list(after["comment"])
+            result["comment"] += after["comment"]
             return result
         result["new_state"] = copy.deepcopy(after["ret"])
     else:
@@ -454,7 +457,8 @@ async def absent(
 
     Args:
         name(str): Idem name of the load balancer.
-        resource_id(str, Optional): The Amazon Resource Name (ARN) of ElasticLoadBalancingv2 Target Group. If the target group does not exist or has already been deleted, the call still succeeds.
+        resource_id(str, Optional): The Amazon Resource Name (ARN) of ElasticLoadBalancingv2 Target Group. If the
+        target group does not exist or has already been deleted, the call still succeeds.
 
     Examples:
         .. code-block:: sls
@@ -465,12 +469,10 @@ async def absent(
                   - resource_id: arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targets/73e2d6bc24d8a067
 
     """
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
+    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     if not resource_id:
-        result["comment"] = list(
-            hub.tool.aws.comment_utils.already_absent_comment(
-                resource_type="aws.elbv2.target_group", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.elbv2.target_group", name=name
         )
         return result
     before = await hub.exec.aws.elbv2.target_group.get(
@@ -482,18 +484,14 @@ async def absent(
         return result
 
     if not before["ret"]:
-        result["comment"] = list(
-            hub.tool.aws.comment_utils.already_absent_comment(
-                resource_type="aws.elbv2.target_group", name=name
-            )
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.elbv2.target_group", name=name
         )
     else:
         result["old_state"] = before["ret"]
         if ctx.get("test", False):
-            result["comment"] = list(
-                hub.tool.aws.comment_utils.would_delete_comment(
-                    resource_type="aws.elbv2.target_group", name=name
-                )
+            result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
+                resource_type="aws.elbv2.target_group", name=name
             )
             return result
         else:
@@ -501,13 +499,11 @@ async def absent(
                 ctx, TargetGroupArn=resource_id
             )
             if not ret["result"]:
-                result["comment"] = list(before["comment"])
+                result["comment"] = before["comment"]
                 result["result"] = False
                 return result
-            result["comment"] = list(
-                hub.tool.aws.comment_utils.delete_comment(
-                    resource_type="aws.elbv2.target_group", name=name
-                )
+            result["comment"] = hub.tool.aws.comment_utils.delete_comment(
+                resource_type="aws.elbv2.target_group", name=name
             )
     return result
 
