@@ -11,7 +11,8 @@ async def present(
 ) -> Dict[str, Any]:
     """Attaches the specified managed policy to the specified IAM role.
 
-    When you attach a managed policy to a role, the managed policy becomes part of the role's permission (access) policy.
+    When you attach a managed policy to a role, the managed policy becomes
+    part of the role's permission (access) policy.
 
     Args:
         name(str):
@@ -19,9 +20,9 @@ async def present(
             to a role.
 
         role_name(str):
-            The name (friendly name, not ARN) of the role to attach a policy. This parameter allows (through its regex pattern )
-            a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also
-            include any of the following characters: _+=,.@-
+            The name (friendly name, not ARN) of the role to attach a policy. This parameter allows
+            (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric
+            characters with no spaces. You can also include any of the following characters: _+=,.@-
 
         policy_arn(str):
             The Amazon Resource Name (ARN) of the IAM policy you want to attach.
@@ -51,6 +52,7 @@ async def present(
 
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
+
     try:
         before_ret = (
             await hub.tool.aws.iam.role_policy_attachment.is_role_policy_attached(
@@ -63,8 +65,23 @@ async def present(
         return result
 
     # If before_ret has False result and has an error message in comment, then immediately return with the error,
-    # and if role does not exists - NoSuchEntityException is expected
+    # If role does not exists - NoSuchEntityException is in the comment, do not fail in 'test' mode.
     if before_ret["result"] is False and before_ret["comment"]:
+        if "NoSuchEntityException" in before_ret["comment"][0] and ctx.get(
+            "test", False
+        ):
+            result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
+                enforced_state={},
+                desired_state={
+                    "role_name": role_name,
+                    "policy_arn": policy_arn,
+                },
+            )
+            result["comment"] = (
+                f"Would create aws.iam.role_policy_attachment. \
+                 Role {role_name}, policy {policy_arn}.",
+            )
+            return result
         result["result"] = False
         result["comment"] = before_ret["comment"]
         return result
@@ -78,20 +95,21 @@ async def present(
         result["new_state"] = copy.deepcopy(result["old_state"])
         result["comment"] = (f"aws.iam.role_policy_attachment '{name}' already exists",)
     else:
-        try:
-            if ctx.get("test", False):
-                result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
-                    enforced_state={},
-                    desired_state={
-                        "role_name": role_name,
-                        "policy_arn": policy_arn,
-                    },
-                )
-                result["comment"] = (
-                    f"Would create aws.iam.role_policy_attachment. Role {role_name}, policy {policy_arn}",
-                )
-                return result
+        if ctx.get("test", False):
+            result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
+                enforced_state={},
+                desired_state={
+                    "role_name": role_name,
+                    "policy_arn": policy_arn,
+                },
+            )
+            result["comment"] = (
+                f"Would create aws.iam.role_policy_attachment. \
+                Role {role_name}, policy {policy_arn}.",
+            )
+            return result
 
+        try:
             ret = await hub.exec.boto3.client.iam.attach_role_policy(
                 ctx,
                 RoleName=role_name,
@@ -123,9 +141,10 @@ async def absent(
             The name of the AWS IAM role policy.
 
         role_name(str):
-            The name (friendly name, not ARN) of the role to attach a policy. This parameter allows (through its regex pattern )
-            a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also
-            include any of the following characters: _+=,.@-
+            The name (friendly name, not ARN) of the role to attach a policy.
+            This parameter allows (through its regex pattern) a string of characters consisting of upper
+            and lowercase alphanumeric characters with no spaces.
+            You can also include any of the following characters: _+=,.@-
 
         policy_arn(str):
             The Amazon Resource Name (ARN) of the IAM policy you want to attach.
