@@ -531,10 +531,8 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             continue
 
         try:
-            translated_resource = (
-                await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present(
-                    ctx, raw_resource=key_details["ret"]["KeyMetadata"]
-                )
+            translated_resource = await hub.tool.aws.kms.conversion_utils.convert_raw_key_to_present_async(
+                ctx, raw_resource=key_details["ret"]["KeyMetadata"]
             )
         except Exception as e:
             hub.log.debug(f"Failed to convert key with Id {key.get('KeyId')}: {e}")
