@@ -640,7 +640,7 @@ async def absent(
     tags = tags["ret"]
     result[
         "old_state"
-    ] = await hub.tool.aws.neptune.db_cluster.convert_raw_db_cluster_to_present(
+    ] = hub.tool.aws.neptune.db_cluster.convert_raw_db_cluster_to_present(
         db_clusters[0], idem_resource_name=resource_id, tags=tags
     )
 
@@ -729,7 +729,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         tags = tags["ret"]
         # Including fields to match the 'present' function parameters
         resource_translated = (
-            await hub.tool.aws.neptune.db_cluster.convert_raw_db_cluster_to_present(
+            hub.tool.aws.neptune.db_cluster.convert_raw_db_cluster_to_present(
                 db_cluster, idem_resource_name=resource_id, tags=tags
             )
         )
