@@ -755,8 +755,10 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             )
             continue
         tags = tags["ret"]
-        resource_translated = await hub.tool.aws.neptune.conversion_utils.convert_raw_db_instance_to_present(
-            db_instance, idem_resource_name=resource_id, tags=tags
+        resource_translated = (
+            hub.tool.aws.neptune.conversion_utils.convert_raw_db_instance_to_present(
+                db_instance, idem_resource_name=resource_id, tags=tags
+            )
         )
         result[resource_id] = {
             "aws.neptune.db_instance.present": [
