@@ -57,8 +57,8 @@ async def present(
             Dict in the format of {tag-key: tag-value} or List of tags in the format of
             [{"Key": tag-key, "Value": tag-value}] to associate with the policy.
 
-            * Key (str, optional): The key identifier, or name, of the tag.
-            * Value (str, optional): The string value that's associated with the key of the tag.
+            * Key (str, Optional): The key identifier, or name, of the tag.
+            * Value (str, Optional): The string value that's associated with the key of the tag.
 
     Request syntax:
         .. code-block:: sls
