@@ -51,34 +51,43 @@ async def present(
 
     A DB cluster parameter group is initially created with the default parameters for the database engine used by
     instances in the DB cluster. To provide custom values for any of the parameters, you must modify the group after
-    creating it using ModifyDBClusterParameterGroup . Once you've created a DB cluster parameter group, you need to
-    associate it with your DB cluster using ModifyDBCluster .
+    creating it using ModifyDBClusterParameterGroup. Once you've created a DB cluster parameter group, you need to
+    associate it with your DB cluster using ModifyDBCluster.
 
     When you associate a new DB cluster parameter group with a running Aurora DB cluster, reboot the DB instances in the
     DB cluster without failover for the new DB cluster parameter group and associated settings to take effect.
 
     Args:
-        name(str): An Idem name of the resource.
-        resource_id(str, Optional): AWS DB Cluster Parameter Group name.
+        name(str):
+            An Idem name of the resource.
 
-        db_parameter_group_family(str): The DB cluster parameter group family name. A DB cluster
-            parameter group can be associated with one and only one DB cluster parameter group family, and can be applied
-            only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter
-            group family.
+        resource_id(str, Optional):
+            AWS DB Cluster Parameter Group name.
+
+        db_parameter_group_family(str):
+            The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and
+            only one DB cluster parameter group family, and can be applied only to a DB cluster running a database
+            engine and engine version compatible with that DB cluster parameter group family.
 
             Example: ``aurora5.6``, ``aurora-postgresql9.6``, ``mysql8.0``, etc.
 
-        description(str): The description for the DB cluster parameter group.
-        tags(Dict or List, Optional): Dict in the format of {tag-key: tag-value} or List of tags in the format of
-            [{"Key": tag-key, "Value": tag-value}] to associate with the DB cluster parameter group.
-            Each tag consists of a key name and an associated value. Defaults to None.
+        description(str):
+            The description for the DB cluster parameter group.
 
-            * Key (str, Optional): The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode
-                characters. May not begin with aws:.
-            * Value(str, Optional): The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 256
-                Unicode characters.
+        tags(Dict or List, Optional):
+            Dict in the format of {tag-key: tag-value} or List of tags in the format of ``[{"Key": tag-key, "Value":
+            tag-value}]`` to associate with the DB cluster parameter group.  Each tag consists of a key name and an
+            associated value. Defaults to None.
+
+            * Key (str, Optional): The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of
+              127 Unicode characters. May not begin with aws:.
+
+            * Value(str, Optional): The value of the tag. Constraints: Tag values are case-sensitive and accept a
+              maximum of 256 Unicode characters.
+
+        parameters(List, Optional):
+            Parameters in the DB parameter group. Defaults to None.
 
-        parameters(List, Optional): parameters in the DB parameter group. Defaults to None.
             Parameter support the following:
 
             * ParameterName (str): Specifies the name of the parameter.
@@ -147,10 +156,13 @@ async def present(
             result["result"] = False
             result["comment"] = before["comment"]
             return result
+
+        result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
+            resource_type="aws.rds.db_cluster_parameter_group", name=name
+        )
         result["old_state"] = copy.deepcopy(before["ret"])
         plan_state = copy.deepcopy(result["old_state"])
 
-        update_tags_ret = None
         # Update tags
         if tags is not None:
             update_tags_ret = await hub.exec.aws.rds.tag.update_rds_tags(
@@ -159,7 +171,7 @@ async def present(
                 old_tags=result["old_state"].get("tags"),
                 new_tags=tags,
             )
-            result["comment"] = update_tags_ret["comment"]
+            result["comment"] += update_tags_ret["comment"]
             result["result"] = update_tags_ret["result"]
             resource_updated = update_tags_ret["result"]
             if ctx.get("test", False) and update_tags_ret["ret"] is not None:
@@ -173,7 +185,7 @@ async def present(
                     new_parameters=parameters,
                 )
             )
-            result["comment"] = result["comment"] + update_ret["comment"]
+            result["comment"] += update_ret["comment"]
             result["result"] = result["result"] and update_ret["result"]
             resource_updated = resource_updated or bool(update_ret["ret"])
             if ctx.get("test", False) and update_ret["ret"] is not None:
@@ -240,7 +252,7 @@ async def present(
                     )
                 )
 
-                result["comment"] = result["comment"] + update_ret["comment"]
+                result["comment"] += update_ret["comment"]
                 result["result"] = result["result"] and update_ret["result"]
     try:
         if ctx.get("test", False):
@@ -251,16 +263,13 @@ async def present(
             )
             if not after["result"] or not after["ret"]:
                 result["result"] = False
-                result["comment"] = after["comment"]
+                result["comment"] += after["comment"]
                 return result
             result["new_state"] = copy.deepcopy(after["ret"])
         else:
             result["new_state"] = copy.deepcopy(result["old_state"])
-            result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
-                resource_type="aws.rds.db_cluster_parameter_group", name=name
-            )
     except Exception as e:
-        result["comment"] = result["comment"] + (str(e),)
+        result["comment"] += (str(e),)
         result["result"] = False
     return result
 
@@ -278,10 +287,12 @@ async def absent(
     DB instances in the Amazon RDS User Guide.
 
     Args:
-        name(str): An Idem name of the resource
-        resource_id(str, Optional): AWS DB Cluster Parameter Group name. Constraints: Must be the name of an existing
-            DB cluster parameter group. You can't delete a default DB cluster parameter group. Can't be associated with
-            any DB clusters.
+        name(str):
+            An Idem name of the resource
+
+        resource_id(str, Optional):
+            AWS DB Cluster Parameter Group name. Constraints: Must be the name of an existing DB cluster parameter
+            group. You can't delete a default DB cluster parameter group. Can't be associated with any DB clusters.
 
     Request Syntax:
         .. code-block:: sls
@@ -342,13 +353,12 @@ async def absent(
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
-    Describe the resource in a way that can be recreated/managed with the corresponding "present" function
+    Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
-    Returns a list of DBClusterParameterGroup descriptions. If a DBClusterParameterGroupName parameter is
-    specified, the list will contain only the description of the specified DB cluster parameter group.  For more
-    information on Amazon Aurora, see  What is Amazon Aurora? in the Amazon Aurora User Guide.  For more information
-    on Multi-AZ DB clusters, see  Multi-AZ deployments with two readable standby DB instances in the Amazon RDS User
-    Guide.
+    Returns a list of DBClusterParameterGroup descriptions. If a DBClusterParameterGroupName parameter is specified,
+    the list will contain only the description of the specified DB cluster parameter group.  For more information on
+    Amazon Aurora, see  What is Amazon Aurora? in the Amazon Aurora User Guide.  For more information on Multi-AZ DB
+    clusters, see  Multi-AZ deployments with two readable standby DB instances in the Amazon RDS User Guide.
 
     Returns:
         Dict[str, Dict[str, Any]]
