@@ -220,10 +220,11 @@ async def present(
         before = await hub.exec.aws.s3.bucket.get(
             ctx, name=name, resource_id=resource_id
         )
-        if not before["result"]:
+        if not before["result"] or not before["ret"]:
             result["comment"] = before["comment"]
             result["result"] = False
             return result
+
         result["old_state"] = copy.deepcopy(before["ret"])
         plan_state = copy.deepcopy(result["old_state"])
         result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
@@ -277,6 +278,28 @@ async def present(
             else:
                 plan_state["tags"] = tags_dict
     else:
+        # If there is no 'resource_id' and 'get_resource_only_with_resource_id' is True,
+        # the request is to create a new bucket.
+        # Since bucket name is unique, we should fail if a bucket with the given name  already exists.
+        # However hub.exec.boto3.client.s3.create_bucket() does not fail if one exists with
+        # the same name. This check will ensure we fail.
+        if hub.OPT.idem.get("get_resource_only_with_resource_id", False):
+            already_exists = await hub.exec.aws.s3.bucket.get(
+                ctx, name=name, resource_id=name
+            )
+            if already_exists["result"] and already_exists["ret"]:
+                result["comment"] = (
+                    result["comment"]
+                    + hub.tool.aws.comment_utils.already_exists_comment(
+                        "aws.s3.bucket", name
+                    )
+                    + (
+                        f"Cannot create a new aws.s3.bucket with the same name '{name}'.",
+                    )
+                )
+                result["result"] = False
+                return result
+
         if ctx.get("test", False):
             result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
                 enforced_state={},
@@ -438,7 +461,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
         try:
             translated_resource = (
-                await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present(
+                await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present_async(
                     ctx, idem_resource_name=resource_id
                 )
             )
