@@ -397,13 +397,7 @@ async def present(
         result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
             resource_type=STATE_NAME, name=name
         )
-        result[
-            "old_state"
-        ] = hub.tool.aws.s3.bucket_lifecycle.convert_raw_bucket_lifecycle_to_present(
-            bucket=resource_id,
-            raw_resource=before_ret.get("ret"),
-            idem_resource_name=name,
-        )
+        result["old_state"] = copy.deepcopy(before_ret["ret"])
         result["new_state"] = copy.deepcopy(result["old_state"])
 
         resource_parameters = {
