@@ -191,7 +191,7 @@ async def present(
             An Idem name of the resource.
             This is also used as the name of the bucket on which replication needs to be configured.
 
-        resource_id(str, optional):
+        resource_id(str, Optional):
             Name of the S3 bucket.
 
         role (str):
@@ -202,32 +202,32 @@ async def present(
             A container for one or more replication rules. A replication configuration must have at least
             one rule and can contain a maximum of 1,000 rules.
 
-            * ID (str, optional):
+            * ID (str, Optional):
                 A unique identifier for the rule. The maximum value is 255 characters.
 
-            * Priority (int, optional):
+            * Priority (int, Optional):
                 The priority indicates which rule has precedence whenever two or more replication rules
                 conflict. Amazon S3 will attempt to replicate objects according to all replication rules.
                 However, if there are two or more rules with the same destination bucket, then objects will be
                 replicated according to the rule with the highest priority. The higher the number, the higher
                 the priority.
 
-            * Prefix (str, optional):
+            * Prefix (str, Optional):
                 An object key name prefix that identifies the object or objects to which the rule applies. The
                 maximum prefix length is 1,024 characters. To include all objects in a bucket, specify an empty
                 string. Replacement must be made for object keys containing special characters (such as
                 carriage returns) when using XML requests.
 
-            * Filter (dict, optional):
+            * Filter (dict, Optional):
                 A filter that identifies the subset of objects to which the replication rule applies. A Filter
                 must specify exactly one Prefix, Tag, or an And child element.
 
-                * Prefix (str, optional):
+                * Prefix (str, Optional):
                     An object key name prefix that identifies the subset of objects to which the rule applies.
                     Replacement must be made for object keys containing special characters (such as carriage
                     returns) when using XML requests.
 
-                * Tag (dict, optional):
+                * Tag (dict, Optional):
                     A container for specifying a tag key and value.  The rule applies only to objects that have the
                     tag in their tag set.
 
@@ -237,28 +237,28 @@ async def present(
                     * Value (str):
                         Value of the tag.
 
-                * And (dict, optional):
+                * And (dict, Optional):
                     A container for specifying rule filters. The filters determine the subset of objects to which
                     the rule applies. This element is required only if you specify more than one filter. For
                     example: If you specify both a Prefix and a Tag filter, wrap these filters in an And tag.
                     If you specify a filter based on multiple tags, wrap the Tag elements in an And tag.
 
-                    * Prefix (str, optional):
+                    * Prefix (str, Optional):
                         An object key name prefix that identifies the subset of objects to which the rule applies.
 
-                    * Tags (list, optional):
+                    * Tags (list, Optional):
                         An array of tags containing key and value pairs.
             * Status (str):
                 Specifies whether the rule is enabled.
 
-            * SourceSelectionCriteria (dict, optional):
+            * SourceSelectionCriteria (dict, Optional):
                 A container that describes additional filters for identifying the source objects that you want
                 to replicate. You can choose to enable or disable the replication of these objects. Currently,
                 Amazon S3 supports only the filter that you can specify for objects created with server-side
                 encryption using a customer managed key stored in Amazon Web Services Key Management Service
                 (SSE-KMS).
 
-                * SseKmsEncryptedObjects (dict, optional):
+                * SseKmsEncryptedObjects (dict, Optional):
                     A container for filter information for the selection of Amazon S3 objects encrypted with Amazon
                     Web Services KMS. If you include SourceSelectionCriteria in the replication configuration, this
                     element is required.
@@ -267,7 +267,7 @@ async def present(
                         Specifies whether Amazon S3 replicates objects created with server-side encryption using an
                         Amazon Web Services KMS key stored in Amazon Web Services Key Management Service.
 
-                * ReplicaModifications (dict, optional):
+                * ReplicaModifications (dict, Optional):
                     A filter that you can specify for selections for modifications on replicas. Amazon S3 doesn't
                     replicate replica modifications by default. In the latest version of replication configuration
                     (when Filter is specified), you can specify this element and set the status to Enabled to
@@ -278,27 +278,27 @@ async def present(
                     * Status (str):
                         Specifies whether Amazon S3 replicates modifications on replicas.
 
-            * ExistingObjectReplication (dict, optional):
+            * ExistingObjectReplication (dict, Optional):
 
                 * Status (str):
 
-            * Destination (Dict[str, Any]):
+            * Destination (dict[str, Any]):
                 A container for information about the replication destination and its configurations including
                 enabling the S3 Replication Time Control (S3 RTC).
 
                 * Bucket (str):  The Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
 
-                * Account (str, optional):
+                * Account (str, Optional):
                     Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to
                     change replica ownership to the Amazon Web Services account that owns the destination bucket by
                     specifying the AccessControlTranslation property, this is the account ID of the destination
                     bucket owner.
 
-                * StorageClass (str, optional):
+                * StorageClass (str, Optional):
                     The storage class to use when replicating objects, such as S3 Standard or reduced redundancy.
                     By default, Amazon S3 uses the storage class of the source object to create the object replica.
 
-                * AccessControlTranslation (dict, optional):
+                * AccessControlTranslation (dict, Optional):
                     Specify this only in a cross-account scenario (where source and destination bucket owners are
                     not the same), and you want to change replica ownership to the Amazon Web Services account that
                     owns the destination bucket. If this is not specified in the replication configuration, the
@@ -307,17 +307,17 @@ async def present(
                     * Owner (str):
                         Specifies the replica ownership.
 
-                * EncryptionConfiguration (dict, optional):
+                * EncryptionConfiguration (dict, Optional):
                     A container that provides information about encryption. If SourceSelectionCriteria is specified,
                     you must specify this element.
 
-                    * ReplicaKmsKeyID (str, optional):
+                    * ReplicaKmsKeyID (str, Optional):
                         Specifies the ID (Key ARN or Alias ARN) of the customer managed Amazon Web Services KMS key
                         stored in Amazon Web Services Key Management Service (KMS) for the destination bucket. Amazon S3
                         uses this key to encrypt replica objects. Amazon S3 only supports symmetric, customer managed
                         KMS keys.
 
-                * ReplicationTime (dict, optional):
+                * ReplicationTime (dict, Optional):
                     A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is
                     enabled and the time when all objects and operations on objects must be replicated. Must be
                     specified together with a Metrics block.
@@ -329,20 +329,20 @@ async def present(
                         A container specifying the time by which replication should be complete for all objects and
                         operations on objects.
 
-                        * Minutes (int, optional):
+                        * Minutes (int, Optional):
                             Contains an integer specifying time in minutes.   Valid value: 15
 
-                * Metrics (dict, optional):
+                * Metrics (dict, Optional):
                     A container specifying replication metrics-related settings enabling replication metrics and
                     events.
 
                     * Status (str):
                         Specifies whether the replication metrics are enabled.
 
-                    * EventThreshold ('ReplicationTimeValue', optional):
+                    * EventThreshold ('ReplicationTimeValue', Optional):
                         A container specifying the time threshold for emitting the s3:Replication:OperationMissedThreshold event.
 
-            * DeleteMarkerReplication (dict, optional):
+            * DeleteMarkerReplication (dict, Optional):
                 Specifies whether Amazon S3 replicates delete markers. If you specify a Filter in your
                 replication configuration, you must also include a DeleteMarkerReplication element. If your
                 Filter includes a Tag element, the DeleteMarkerReplication Status must be set to Disabled,
@@ -351,11 +351,11 @@ async def present(
                 replication, see Basic Rule Configuration.   If you are using an earlier version of the
                 replication configuration, Amazon S3 handles replication of delete markers differently.
 
-                * Status (str, optional):
+                * Status (str, Optional):
                     Indicates whether to replicate delete markers.  Indicates whether to replicate delete markers.
 
     Request Syntax:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             [bucket_name]-replication:
               aws.s3.bucket_replication.present:
@@ -385,10 +385,10 @@ async def present(
                   Status: "string"
 
     Returns:
-        Dict[str, Any]
+        dict[str, Any]
 
     Examples:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             resource_is_present:
               aws.s3.bucket_replication.present:
@@ -513,7 +513,7 @@ async def absent(
         resource_id(str): Name of the bucket on which replication needs to be deleted.
 
     Request Syntax:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             [bucket_name]-replication:
               aws.s3.bucket_replication.absent:
@@ -521,10 +521,10 @@ async def absent(
                 - resource_id: "string"
 
     Returns:
-        Dict[str, Any]
+        dict[str, Any]
 
     Examples:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             test-bucket-replication:
               aws.s3.bucket_replication.absent:
@@ -580,7 +580,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Returns:
-        Dict[str, Dict[str, Any]]
+        dict[str, dict[str, Any]]
 
     Examples:
         .. code-block:: bash
