@@ -5,7 +5,7 @@ from typing import Dict
 from typing import List
 
 
-async def convert_raw_integration_response_to_present(
+def convert_raw_integration_response_to_present(
     hub,
     raw_resource: Dict[str, Any],
     resource_id: str,
