@@ -47,27 +47,19 @@ async def get_updated_payload_delivery_channel(
     update_payload = {}
     delivery_props = {}
 
-    if s3_bucket_name and before.get("s3BucketName") != s3_bucket_name:
+    if s3_bucket_name:
         update_payload["s3BucketName"] = s3_bucket_name
 
-    if s3_key_prefix and before.get("s3KeyPrefix") != s3_key_prefix:
+    if s3_key_prefix:
         update_payload["s3KeyPrefix"] = s3_key_prefix
 
-    if s3_kms_key_arn and before.get("s3KmsKeyArn") != s3_kms_key_arn:
+    if s3_kms_key_arn:
         update_payload["s3KmsKeyArn"] = s3_kms_key_arn
 
-    if sns_topic_arn and before.get("snsTopicARN") != sns_topic_arn:
+    if sns_topic_arn:
         update_payload["snsTopicARN"] = sns_topic_arn
 
-    if (
-        config_snapshot_delivery_properties
-        and not before.get("configSnapshotDeliveryProperties")
-    ) or (
-        config_snapshot_delivery_properties
-        and before.get("configSnapshotDeliveryProperties")
-        and before.get("configSnapshotDeliveryProperties").get("deliveryFrequency")
-        != config_snapshot_delivery_properties.get("delivery_frequency")
-    ):
+    if config_snapshot_delivery_properties:
         delivery_props["deliveryFrequency"] = config_snapshot_delivery_properties[
             "delivery_frequency"
         ]
@@ -75,7 +67,6 @@ async def get_updated_payload_delivery_channel(
 
     if update_payload:
         update_payload["name"] = resource_id
-        update_payload["s3BucketName"] = s3_bucket_name
         result["ret"] = update_payload
         result["result"] = True
 
