@@ -184,13 +184,11 @@ async def update(
 
     table_parameters = OrderedDict(
         {
-            "attribute_definitions": "AttributeDefinitions",
             "billing_mode": "BillingMode",
             "global_secondary_indexes": "GlobalSecondaryIndexUpdates",
             "provisioned_throughput": "ProvisionedThroughput",
             "replica_updates": "ReplicaUpdates",
             "stream_specification": "StreamSpecification",
-            "sse_specification": "SSESpecification",
             "table_class": "TableClass",
         }
     )
@@ -214,6 +212,18 @@ async def update(
                 "GlobalSecondaryIndexUpdates"
             ] = global_secondary_indexes
 
+    new_sse_specification = desired_state.get("sse_specification")
+    old_sse_specification = old_state.get("sse_specification")
+    if new_sse_specification != old_sse_specification:
+        if new_sse_specification.get("Enabled") != old_sse_specification.get(
+            "Enabled"
+        ) or (
+            new_sse_specification.get("KMSMasterKeyId")
+            and new_sse_specification.get("KMSMasterKeyId")
+            != old_sse_specification.get("KMSMasterKeyId")
+        ):
+            table_parameters_to_update["SSESpecification"] = new_sse_specification
+
     replica_updates = desired_state.get("replica_updates")
     if replica_updates is not None:
         if not hub.tool.aws.state_comparison_utils.are_lists_identical(
