@@ -1,14 +1,13 @@
 """
 Contains functions that are useful for describing instances in a consistent manner
 """
-import asyncio
 import base64
 from typing import Any
 from typing import Dict
 from typing import Tuple
 
 
-async def convert_to_present(
+async def convert_instance_to_present_async(
     hub, ctx, describe_instances: Dict[str, Any], name: str = None
 ) -> Dict[str, Any]:
     """
@@ -17,24 +16,45 @@ async def convert_to_present(
     This is the preferred "meta" function for collecting information about multiple instances
     """
     result = {}
-    coros = []
     for reservation in describe_instances.get("Reservations", []):
         for instance in reservation["Instances"]:
             instance_id = instance["InstanceId"]
             placement = instance.get("Placement", {})
             metadata_options = instance.get("MetadataOptions", {})
             private_dns_name_options = instance.get("PrivateDnsNameOptions", {})
+            network_interfaces = [
+                {
+                    "network_interface_id": n.get("NetworkInterfaceId"),
+                    "device_index": n.get("Attachment", {}).get("DeviceIndex"),
+                    "network_card_index": n.get("Attachment", {}).get(
+                        "NetworkCardIndex"
+                    ),
+                }
+                for n in instance.get("NetworkInterfaces", [])
+            ]
+            block_device_mappings = [
+                dict(
+                    device_name=bdm["DeviceName"],
+                    delete_on_termination=bdm.get("Ebs", {}).get(
+                        "delete_on_termination"
+                    ),
+                    volume_id=bdm.get("Ebs", {}).get("volume_id"),
+                )
+                for bdm in instance.get("BlockDeviceMappings", [])
+            ]
             result[instance_id] = dict(
                 name=name or instance_id,
                 resource_id=instance_id,
                 image_id=instance.get("ImageId"),
                 instance_type=instance.get("InstanceType"),
-                volume_attachments=None,
-                block_device_mappings=instance.get("BlockDeviceMappings"),
+                block_device_mappings=block_device_mappings,
                 ebs_optimized=instance.get("EbsOptimized"),
                 kernel_id=instance.get("KernelId"),
                 subnet_id=instance.get("SubnetId"),
-                network_interfaces=instance.get("NetworkInterfaces"),
+                security_group_ids=[
+                    sg.get("GroupId") for sg in instance.get("SecurityGroups", [])
+                ],
+                network_interfaces=network_interfaces,
                 monitoring_enabled=instance.get("Monitoring", {}).get("State")
                 == "enabled",
                 root_device_name=instance.get("RootDeviceName"),
@@ -42,6 +62,8 @@ async def convert_to_present(
                 product_codes=instance.get("ProductCodes"),
                 source_dest_check=instance.get("SourceDestCheck"),
                 running=instance.get("State", {}).get("Name") == "running",
+                # Possible values are: pending, running, shutting-down, terminated, stopping, stopped
+                instance_state=instance.get("State", {}).get("Name"),
                 private_ip_address=instance.get("PrivateIpAddress"),
                 reservation_id=reservation.get("ReservationId"),
                 owner_id=reservation.get("OwnerId"),
@@ -70,7 +92,7 @@ async def convert_to_present(
                 ),
                 sriov_net_support=instance.get("SriovNetSupport"),
                 key_name=instance.get("KeyName"),
-                elastic_gpu_specificatiosn=instance.get("ElasticGpuAssociations"),
+                elastic_gpu_specifications=instance.get("ElasticGpuAssociations"),
                 nitro_enclave_enabled=instance.get("EnclaveOptions", {}).get("Enabled"),
                 license_arns=[
                     license_["LicenseConfigurationArn"]
@@ -117,37 +139,30 @@ async def convert_to_present(
                 ] = await hub.tool.aws.ec2.instance.state.parse_block_device_mapping(
                     ctx, instance.get("BlockDeviceMappings")
                 )
-            coros.append(
-                # launch_template config get most parameters for an instance
-                hub.tool.aws.ec2.instance.state.config(ctx, instance_id=instance_id)
+            _, config = await hub.tool.aws.ec2.instance.state.config(
+                ctx, instance_id=instance_id
             )
-
-    # This can be a heavy process if there are many instances, use coroutines to collect them all at simultaneously
-    for ret in asyncio.as_completed(coros):
-        instance_id, config = await ret
-        result[instance_id].update(config)
+            # If some values were defined in the launch config, but not in describe_instances, fill them in here
+            for k, v in config.items():
+                if not result[instance_id].get(k):
+                    result[instance_id][k] = v
 
     return hub.tool.aws.ec2.instance.data.sanitize_dict(result)
 
 
 async def parse_block_device_mapping(hub, ctx, block_device_mappings):
+    new_block_device_mappings = list()
     for bdm in block_device_mappings:
-        ebs = bdm.get("Ebs")
-        volume_id = ebs.get("VolumeId")
-        ret = await hub.exec.boto3.client.ec2.describe_volumes(
-            ctx, VolumeIds=[volume_id]
+        ebs = bdm.get("Ebs", {})
+        new_bdm = dict(
+            device_name=bdm["DeviceName"],
         )
-        new_ebs = {"DeleteOnTermination": ebs.get("DeleteOnTermination")}
-        if ret:
-            for volume in ret.ret.get("Volumes", ()):
-                new_ebs["VolumeSize"] = volume.get("Size")
-                new_ebs["VolumeType"] = volume.get("VolumeType")
-                new_ebs["SnapshotId"] = volume.get("SnapshotId")
-                new_ebs["Iops"] = volume.get("Iops")
-                new_ebs["Throughput"] = volume.get("Throughput")
-                new_ebs["Encrypted"] = volume.get("Encrypted")
-        bdm["Ebs"] = new_ebs
-    return block_device_mappings
+        if ebs.get("VolumeId"):
+            new_bdm["volume_id"] = ebs["VolumeId"]
+        if ebs.get("DeleteOnTermination"):
+            new_bdm["delete_on_termination"] = ebs["DeleteOnTermination"]
+        new_block_device_mappings.append(new_bdm)
+    return new_block_device_mappings
 
 
 async def config(hub, ctx, *, instance_id: str) -> Tuple[str, Dict[str, Any]]:
@@ -229,7 +244,7 @@ def parse_launch_template_data(hub, **launch_config) -> Dict[str, Any]:
         ebs_optimized=launch_config.get("EbsOptimized"),
         kernel_id=launch_config.get("KernelId"),
         # subnet_id=None,
-        network_interfaces=launch_config.get("NetworkInterfaces"),
+        # network_interfaces=network_interfaces,
         monitoring_enabled=launch_config.get("Monitoring", {}).get("Enabled"),
         # root_device_name
         # product_codes
@@ -302,52 +317,60 @@ async def attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
     """
     instance = {}
 
-    ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
+    response = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="userData", InstanceId=instance_id
     )
-    if ret:
-        user_data = ret.ret.get("UserData")
+    if response and "UserData" in response.ret:
+        user_data = response.ret.get("UserData")
         if user_data:
-            user_data = base64.b64decode(user_data).decode()
+            user_data = base64.b64decode(user_data.get("Value")).decode()
         instance["user_data"] = user_data
 
-    ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
+    response = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="disableApiTermination", InstanceId=instance_id
     )
-    if ret:
-        instance["disable_api_termination"] = ret.ret["DisableApiTermination"].get(
+    # Response format: 'ret': {'DisableApiTermination': {'Value': False/True}
+    if response and response.ret and "DisableApiTermination" in response.ret:
+        instance["disable_api_termination"] = response.ret["DisableApiTermination"].get(
             "Value"
         )
 
-    ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
+    response = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="instanceInitiatedShutdownBehavior", InstanceId=instance_id
     )
-    if ret:
-        instance["instance_initiated_shutdown_behavior"] = ret.ret[
+    if (
+        response
+        and response.ret
+        and "InstanceInitiatedShutdownBehavior" in response.ret
+    ):
+        instance["instance_initiated_shutdown_behavior"] = response.ret[
             "InstanceInitiatedShutdownBehavior"
         ].get("Value")
 
-    ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
+    response = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="enclaveOptions", InstanceId=instance_id
     )
-    if ret:
+    if response and response.ret and "EnclaveOptions" in response.ret:
         # This is not supported by AWS yet
-        instance["enclave_options"] = ret.ret["EnclaveOptions"]["Enabled"]
+        instance["enclave_options"] = response.ret["EnclaveOptions"]["Enabled"]
 
-    ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
+    response = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="ramdisk", InstanceId=instance_id
     )
-    if ret:
-        instance["ram_disk_id"] = ret.ret["RamdiskId"]
 
-    ret = await hub.exec.boto3.client.ec2.describe_tags(
+    if response and response.ret and "RamdiskId" in response.ret:
+        instance["ram_disk_id"] = response.ret["RamdiskId"]
+
+    response = await hub.exec.boto3.client.ec2.describe_tags(
         ctx,
         Filters=[
             {"Name": "resource-id", "Values": [instance_id]},
         ],
     )
-    if ret:
-        instance["tags"] = {tag["Key"]: tag.get("Value") for tag in ret.ret["Tags"]}
+    if response and response.ret and "Tags" in response.ret:
+        instance["tags"] = {
+            tag["Key"]: tag.get("Value") for tag in response.ret["Tags"]
+        }
 
     return instance
 
@@ -360,12 +383,14 @@ async def extended_attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
     instance = {}
 
     # iam_instance_profile_arn
-    ret = await hub.exec.boto3.client.ec2.describe_iam_instance_profile_associations(
-        ctx, Filters=[{"Name": "instance-id", "Values": [instance_id]}]
+    response = (
+        await hub.exec.boto3.client.ec2.describe_iam_instance_profile_associations(
+            ctx, Filters=[{"Name": "instance-id", "Values": [instance_id]}]
+        )
     )
-    if ret:
+    if response and response.ret and "IamInstanceProfileAssociations" in response.ret:
         instance["iam_instance_profile_arn"] = {}
-        for association in ret.ret["IamInstanceProfileAssociations"]:
+        for association in response.ret["IamInstanceProfileAssociations"]:
             if association["State"] == "associating":
                 # Prefer reporting what will soon be true
                 instance["iam_instance_profile_arn"] = association[
@@ -385,25 +410,11 @@ async def extended_attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
                 # Don't break, this might be disassociated
 
     # sriov_net_support
-    ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
+    response = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="sriovNetSupport", InstanceId=instance_id
     )
-    if ret:
-        instance["sriov_net_support"] = ret.ret["SriovNetSupport"].get("Value")
-
-    # volume attachments
-    volume_attachments = {}
-    ret = await hub.exec.boto3.client.ec2.describe_volumes(
-        ctx, Filters=[{"Name": "attachment.instance-id", "Values": [instance_id]}]
-    )
-    if ret:
-        for volume in ret.ret.get("Volumes", ()):
-            for attachment in volume.get("Attachments", ()):
-                if attachment["InstanceId"] == instance_id:
-                    device = attachment["Device"]
-                    volume_attachments[device] = volume["VolumeId"]
-
-    instance["volume_attachments"] = volume_attachments
+    if response and response.ret and "SriovNetSupport" in response.ret:
+        instance["sriov_net_support"] = response.ret["SriovNetSupport"].get("Value")
 
     # bootstrap
     bootstraps = []
