@@ -15,15 +15,18 @@ async def apply(
         new_value: The desired value from the ec2 instance present state parameters
         comments: A running list of comments abound the update process
     """
-    if new_value is True:
+    if new_value:
         # Start monitoring the instance
         ret = await hub.exec.boto3.client.ec2.monitor_instances(
             ctx, InstanceIds=[resource.id]
         )
         if ret.comment:
             comments.append(ret.comment)
+
+        await hub.pop.loop.sleep(1)
+
         return ret.result
-    elif new_value is False:
+    else:
         # Stop monitoring the instance
         ret = await hub.exec.boto3.client.ec2.unmonitor_instances(
             ctx, InstanceIds=[resource.id]
@@ -31,4 +34,5 @@ async def apply(
 
         if ret.comment:
             comments.append(ret.comment)
+
         return ret.result
