@@ -7,6 +7,7 @@ __update_group__ = [
     "affinity",
     "host_id",
     "tenancy",
+    "group_name",
     "partition_number",
     "host_resource_group_arn",
 ]
@@ -35,12 +36,17 @@ async def apply(
     """
     result = True
 
+    group_name = new_value.get("group_name")
+    if "group_name" in old_value and not new_value.get("group_name"):
+        # An empty string removes the instance from the placement group
+        group_name = ""
+
     # Modify the placement
     ret = await hub.exec.boto3.client.ec2.modify_instance_placement(
         ctx,
         InstanceId=resource.id,
         Affinity=new_value.get("affinity"),
-        GroupName=new_value.get("group_name"),
+        GroupName=group_name,
         HostId=new_value.get("host_id"),
         Tenancy=new_value.get("tenancy"),
         PartitionNumber=new_value.get("partition_number"),
