@@ -1,5 +1,8 @@
 from typing import List
 
+# The instance must be stopped to modify this value
+__update_state__ = "stopped"
+
 
 async def apply(
     hub, ctx, resource, *, old_value, new_value, comments: List[str]
@@ -23,11 +26,12 @@ async def apply(
             comments.append(ret.comment)
         return ret.result
     else:
-        ret = await hub.exec.boto3.client.ec2.modfiy_instance_attribute(
+        b64_user_data = new_value.encode()
+        ret = await hub.exec.boto3.client.ec2.modify_instance_attribute(
             ctx,
             InstanceId=resource.id,
-            Attribute="userData",
-            UserData={"Value": new_value},
+            # Attribute="userData",
+            UserData={"Value": b64_user_data},
         )
         if ret.comment:
             comments.append(ret.comment)
