@@ -37,8 +37,8 @@ async def search_raw(hub, ctx, resource_id: str = None, filters: List = None) ->
     Fetch one or more route table from AWS. The return will be in the same format as what the boto3 api returns.
 
     Args:
-        resource_id(Text, optional): AWS route table ID to identify the resource.
-        filters(list, optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+        resource_id(str, Optional): AWS route table ID to identify the resource.
+        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
          https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_route_tables
 
     Returns:
