@@ -156,7 +156,6 @@ async def update_replication_group(
     snapshot_retention_limit: int = None,
     snapshot_window: str = None,
     cache_node_type: str = None,
-    auth_token: str = None,
     auto_token_update_strategy: str = None,
     user_group_ids_to_add: List[str] = None,
     user_group_ids_to_remove: List[str] = None,
@@ -252,14 +251,6 @@ async def update_replication_group(
         snapshot_window(str, Optional): The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your
             node group (shard). Example: 05:00-09:00  If you do not specify this parameter, ElastiCache
             automatically chooses an appropriate time range. Defaults to None.
-        auth_token(str, Optional):  Reserved parameter. The password used to access a password protected server.  AuthToken can be
-            specified only on replication groups where TransitEncryptionEnabled is true.  For HIPAA
-            compliance, you must specify TransitEncryptionEnabled as true, an AuthToken, and a
-            CacheSubnetGroup.  Password constraints:   Must be only printable ASCII characters.   Must be at
-            least 16 characters and no more than 128 characters in length.   The only permitted printable
-            special characters are !, &, #, $, ^, <, >, and -. Other printable special characters cannot be
-            used in the AUTH token.   For more information, see AUTH password at
-            http://redis.io/commands/AUTH. Defaults to None.
         cache_node_type(str, Optional): The compute and memory capacity of the nodes in the node group (shard). The following node types
             are supported by ElastiCache. Generally speaking, the current generation types provide more
             memory and computational power at lower cost when compared to their equivalent previous
@@ -305,13 +296,11 @@ async def update_replication_group(
             "NotificationTopicArn": "notification_topic_arn",
             "CacheParameterGroupName": "cache_parameter_group_name",
             "NotificationTopicStatus": "notification_topic_status",
-            "ApplyImmediately": "apply_immediately",
             "EngineVersion": "engine_version",
             "AutoMinorVersionUpgrade": "auto_minor_version_upgrade",
             "SnapshotRetentionLimit": "snapshot_retention_limit",
             "SnapshotWindow": "snapshot_window",
             "CacheNodeType": "cache_node_type",
-            "AuthToken": "auth_token",
             "AuthTokenUpdateStrategy": "auto_token_update_strategy",
             "UserGroupIdsToAdd": "user_group_ids_to_add",
             "UserGroupIdsToRemove": "user_group_ids_to_remove",
@@ -335,6 +324,11 @@ async def update_replication_group(
             for key, value in params_to_modify.items():
                 plan_state[modify_params.get(key)] = value
         else:
+            # apply_immediately is only used in update to decide whether to apply the update immediate or not
+            # this property is not returned in describe, so this should not be compared with old_state as this
+            # property will not be present in old_state.
+            if apply_immediately is not None:
+                params_to_modify["ApplyImmediately"] = apply_immediately
             modify_ret = (
                 await hub.exec.boto3.client.elasticache.modify_replication_group(
                     ctx, ReplicationGroupId=resource_id, **params_to_modify
