@@ -14,8 +14,8 @@ async def search_raw(
 
     :param hub: idem hub
     :param ctx: idem context
-    :param name: (string) idem name
-    :param resource_id: (string) resource_id maps to DBClusterParameterGroupName attribute for AWS neptune service
+    :param name: (str) idem name
+    :param resource_id: (str) resource_id maps to DBClusterParameterGroupName attribute for AWS neptune service
     :param filters: This is not supported for AWS neptune yet as per AWS documentation.
     :return: Raw representation of one or more AWS neptune DBClusterParameterGroup objects.
     """
