@@ -21,7 +21,7 @@ def convert_raw_resource_record_to_present(
         Idem representation of the resource record.
     """
 
-    name = raw_resource["Name"]
+    name = hub.tool.aws.string_utils.unescape_ascii(raw_resource["Name"])
     record_type = raw_resource["Type"]
     if hosted_zone_id.startswith("/hostedzone/"):
         canonical_hosted_zone_id = hosted_zone_id
