@@ -1,3 +1,4 @@
+"""Tool module for managing Amazon S3 bucket policy."""
 from typing import Any
 from typing import Dict
 
@@ -14,16 +15,18 @@ async def update(
     """Updates an AWS Bucket ACL resource.
 
     Args:
-        hub: required for functions in hub.
-        ctx: context.
-        resource_id(str): ACL Policy name identifier in Amazon Web Services.
-        raw_resource(Dict): Existing resource parameters in Amazon Web Services.
-        access_control_policy(Dict): Parameters from SLS file.
+        resource_id(str):
+            ACL Policy name identifier in Amazon Web Services.
+
+        raw_resource(Dict):
+            Existing resource parameters in Amazon Web Services.
+
+        access_control_policy(Dict):
+            Parameters from SLS file.
 
     Returns:
         Dict[str, Any]
     """
-
     result = dict(comment=(), result=True, ret=None)
 
     acl_policy_diff = data.recursive_diff(
