@@ -66,7 +66,7 @@ def convert_raw_regex_pattern_set_to_present(
     return resource_translated
 
 
-async def convert_raw_web_acl_to_present(
+async def convert_raw_web_acl_to_present_async(
     hub,
     ctx,
     raw_resource: Dict[str, Any],
