@@ -105,7 +105,7 @@ def resource(hub, path: str, context):
         .. code-block: python
 
             # resource will be reusable for more operation calls
-            resource = hub.tool.boto3.resource.create(ctx, "Vpc", id="vpc-71d00419")
+            resource = await hub.tool.boto3.resource.create(ctx, "Vpc", id="vpc-71d00419")
 
             # ret will contain the raw result of the operation call
             ret = await hub.tool.boto3.resource.exec(resource, "create_subnet", CidrBlock="10.0.0.0/24")
@@ -143,7 +143,7 @@ def resource(hub, path: str, context):
             elif operation:
                 # There's a function call to make on this resource
                 # Run the operation with the given parameters
-                resource_ = hub.tool.boto3.resource.create(
+                resource_ = await hub.tool.boto3.resource.create(
                     ctx, service_name, resource_class, *args
                 )
                 result["ret"] = await hub.tool.boto3.resource.exec(
@@ -152,7 +152,7 @@ def resource(hub, path: str, context):
                 result["comment"] = (f"{resource_.__class__.__name__}.{operation}",)
             else:
                 # The path ends with the resource name describe it with the given parameters
-                resource_ = hub.tool.boto3.resource.create(
+                resource_ = await hub.tool.boto3.resource.create(
                     ctx, service_name, resource_class, *args, **kwargs
                 )
                 # Return raw information about the object
