@@ -9,6 +9,11 @@ import boto3.session
 __func_alias__ = {"exec_": "exec", "dict_": "dict", "id_": "id"}
 
 
+def __init__(hub):
+    # A store to re-use existing sessions
+    hub.tool.boto3.resource.STORE = {}
+
+
 async def create(
     hub,
     ctx,
@@ -33,9 +38,18 @@ async def create(
         botocore_session=None
     )
     kwargs = await hub.tool.boto3.session.kwargs(ctx)
-    resource: boto3.resources.factory.ResourceFactory = session.resource(
-        service_name=service_name, **kwargs
-    )
+    config = kwargs.pop("config")
+    session_key = hash((service_name, tuple(sorted(kwargs.items()))))
+    kwargs["config"] = config
+
+    if session_key not in hub.tool.boto3.resource.STORE:
+        resource: boto3.resources.factory.ResourceFactory = session.resource(
+            service_name=service_name, **kwargs
+        )
+        hub.tool.boto3.resource.STORE[session_key] = resource
+    else:
+        # Use existing resource
+        resource = hub.tool.boto3.resource.STORE[session_key]
 
     # Don't pass kwargs that have a "None" value to the function call
     kwargs = {k: v for k, v in resource_kwargs.items() if v is not None}
